-- Take note the new format uses FAC_CODE, NUMBER in the same order as messages2.sql.
set bulk_insert INSERT INTO SYSTEM_ERRORS (SQL_CODE, SQL_CLASS, SQL_SUBCLASS, FAC_CODE, NUMBER, GDS_SYMBOL, SEVERITY, SEVERITY_TEXT) VALUES (?, ?, ?, ?, ?, ?, ?, ?);
-- JRD
(-802, '22', '000', 0, 1, 'arith_except', NULL, 'ERROR')
(-901, 'HY', '000', 0, 2, 'bad_dbkey', NULL, 'ERROR')
(-922, 'HY', '000', 0, 3, 'bad_db_format', NULL, 'ERROR')
(-904, '08', '003', 0, 4, 'bad_db_handle', NULL, 'ERROR')
(-924, 'HY', '000', 0, 5, 'bad_dpb_content', NULL, 'ERROR')
(-901, 'HY', '000', 0, 6, 'bad_dpb_form', NULL, 'ERROR')
(-901, '42', '000', 0, 7, 'bad_req_handle', NULL, 'ERROR')
(-901, '42', '000', 0, 8, 'bad_segstr_handle', NULL, 'ERROR')
(-901, '42', '000', 0, 9, 'bad_segstr_id', NULL, 'ERROR')
(-901, 'HY', '000', 0, 10, 'bad_tpb_content', NULL, 'ERROR')
(-901, 'HY', '000', 0, 11, 'bad_tpb_form', NULL, 'ERROR')
(-901, '08', '003', 0, 12, 'bad_trans_handle', NULL, 'ERROR')
(-902, 'XX', '000', 0, 13, 'bug_check', NULL, 'SEVERE')
(-413, '22', '018', 0, 14, 'convert_error', NULL, 'ERROR')
(-902, 'XX', '001', 0, 15, 'db_corrupt', NULL, 'SEVERE')
(-913, '40', '001', 0, 16, 'deadlock', NULL, 'ERROR')
(-901, 'HY', '000', 0, 17, 'excess_trans', NULL, 'ERROR')
(100, '01', '000', 0, 18, 'from_no_match', NULL, 'ERROR')
(-901, 'HY', '000', 0, 19, 'infinap', 0, 'WARNING')
(-901, 'HY', '000', 0, 20, 'infona', NULL, 'WARNING')
(-901, 'HY', '000', 0, 21, 'infunk', NULL, 'WARNING')
(-901, '27', '000', 0, 22, 'integ_fail', NULL, 'ERROR')
(-104, 'HY', '000', 0, 23, 'invalid_blr', NULL, 'ERROR')
(-902, '08', '001', 0, 24, 'io_error', 4, 'SEVERE')
(-901, '40', '001', 0, 25, 'lock_conflict', NULL, 'ERROR')
(-902, 'XX', '001', 0, 26, 'metadata_corrupt', NULL, 'SEVERE')
(-625, '23', '000', 0, 27, 'not_valid', NULL, 'ERROR')
(-508, '22', '000', 0, 28, 'no_cur_rec', NULL, 'ERROR')
(-803, '23', '000', 0, 29, 'no_dup', NULL, 'ERROR')
(-901, 'HY', '000', 0, 30, 'no_finish', NULL, 'INFO')
(-607, '42', '000', 0, 31, 'no_meta_update', NULL, 'ERROR')
(-551, '28', '000', 0, 32, 'no_priv', NULL, 'ERROR')
(-901, 'HY', '000', 0, 33, 'no_recon', NULL, 'ERROR')
(100, '01', '000', 0, 34, 'no_record', NULL, 'ERROR')
(-901, 'HY', '000', 0, 35, 'no_segstr_close', NULL, 'ERROR')
(-820, 'HY', '000', 0, 36, 'obsolete_metadata', 2, 'ERROR')
(-901, '01', '002', 0, 37, 'open_trans', 2, 'ERROR')
(-901, 'HY', '000', 0, 38, 'port_len', 2, 'ERROR')
(-151, '42', '000', 0, 39, 'read_only_field', 2, 'ERROR')
(-150, '42', '000', 0, 40, 'read_only_rel', 2, 'ERROR')
(-817, '42', '000', 0, 41, 'read_only_trans', 2, 'ERROR')
(-150, '42', '000', 0, 42, 'read_only_view', 2, 'ERROR')
(-901, '25', '000', 0, 43, 'req_no_trans', 2, 'ERROR')
(-901, 'HY', '000', 0, 44, 'req_sync', 2, 'ERROR')
(-901, 'HY', '000', 0, 45, 'req_wrong_db', 2, 'ERROR')
(101, '01', '000', 0, 46, 'segment', 1, 'SUCCESS')
(100, '01', '000', 0, 47, 'segstr_eof', 2, 'ERROR')
(-402, 'HY', '000', 0, 48, 'segstr_no_op', 2, 'ERROR')
(-901, 'HY', '000', 0, 49, 'segstr_no_read', 2, 'ERROR')
(-901, 'HY', '000', 0, 50, 'segstr_no_trans', 2, 'ERROR')
(-817, 'HY', '000', 0, 51, 'segstr_no_write', 2, 'ERROR')
(-901, 'HY', '000', 0, 52, 'segstr_wrong_db', 2, 'ERROR')
(-902, 'HY', '000', 0, 53, 'sys_request', 4, 'SEVERE')
(-596, 'HY', '109', 0, 54, 'stream_eof', 2, 'ERROR')
(-904, '08', '001', 0, 55, 'unavailable', NULL, 'ERROR')
(-901, 'HY', '000', 0, 56, 'unres_rel', NULL, 'ERROR')
(-901, 'HY', '000', 0, 57, 'uns_ext', NULL, 'SEVERE')
(-901, '0A', '000', 0, 58, 'wish_list', NULL, 'SEVERE')
(-820, 'HY', '000', 0, 59, 'wrong_ods', NULL, 'SEVERE')
(-804, '07', '002', 0, 60, 'wronumarg', NULL, 'ERROR')
(-904, '54', '000', 0, 61, 'imp_exc', NULL, 'ERROR')
(-901, 'HY', '000', 0, 62, 'random', NULL, 'ERROR')
(-901, 'HY', '000', 0, 63, 'fatal_conflict', NULL, 'ERROR')
(-902, 'XX', '000', 0, 64, 'badblk', NULL, NULL)
(-902, 'XX', '000', 0, 65, 'invpoolcl', NULL, NULL)
(-904, 'HY', '000', 0, 66, 'nopoolids', NULL, NULL)
(-902, 'XX', '000', 0, 67, 'relbadblk', NULL, NULL)
(-902, '54', '000', 0, 68, 'blktoobig', NULL, NULL)
(-904, 'HY', '001', 0, 69, 'bufexh', NULL, NULL)
(-104, 'HY', '000', 0, 70, 'syntaxerr', NULL, NULL)
(-904, 'HY', '000', 0, 71, 'bufinuse', NULL, NULL)
(-901, 'XX', '000', 0, 72, 'bdbincon', NULL, NULL)
(-904, 'HY', '000', 0, 73, 'reqinuse', NULL, NULL)
(-902, 'HY', '000', 0, 74, 'badodsver', NULL, NULL)
(-219, '42', 'S02', 0, 75, 'relnotdef', NULL, NULL)
(-205, '42', 'S22', 0, 76, 'fldnotdef', NULL, NULL)
(-902, 'XX', '000', 0, 77, 'dirtypage', NULL, NULL)
(-902, 'XX', '000', 0, 78, 'waifortra', NULL, NULL)
(-902, 'XX', '000', 0, 79, 'doubleloc', NULL, NULL)
(-902, 'XX', '000', 0, 80, 'nodnotfnd', NULL, NULL)
(-902, 'XX', '000', 0, 81, 'dupnodfnd', NULL, NULL)
(-902, 'XX', '000', 0, 82, 'locnotmar', NULL, NULL)
(-689, '42', '000', 0, 83, 'badpagtyp', NULL, NULL)
(-902, 'XX', '000', 0, 84, 'corrupt', NULL, NULL)
(-902, '42', '000', 0, 85, 'badpage', NULL, NULL)
(-902, 'XX', '002', 0, 86, 'badindex', NULL, NULL)
(-901, 'HY', '000', 0, 87, 'dbbnotzer', NULL, NULL)
(-901, '25', '000', 0, 88, 'tranotzer', 2, NULL)
(-902, '25', '000', 0, 89, 'trareqmis', NULL, NULL)
(-902, 'HY', '000', 0, 90, 'badhndcnt', NULL, NULL)
(-902, 'HY', '000', 0, 91, 'wrotpbver', NULL, NULL)
(-902, 'HY', '000', 0, 92, 'wroblrver', NULL, NULL)
(-902, 'HY', '000', 0, 93, 'wrodpbver', NULL, NULL)
(-402, '42', '000', 0, 94, 'blobnotsup', NULL, NULL)
(-902, 'XX', '001', 0, 95, 'badrelation', NULL, NULL)
(-902, 'XX', '000', 0, 96, 'nodetach', NULL, NULL)
(-902, 'XX', '000', 0, 97, 'notremote', NULL, NULL)
(-901, '25', '000', 0, 98, 'trainlim', NULL, NULL)
(-901, '25', '000', 0, 99, 'notinlim', NULL, NULL)
(-901, '25', '000', 0, 100, 'traoutsta', NULL, NULL)
(-923, '08', '004', 0, 101, 'connect_reject', NULL, NULL)
(-902, 'XX', '000', 0, 102, 'dbfile', NULL, NULL)
(-902, 'XX', '000', 0, 103, 'orphan', NULL, NULL)
(-904, 'HY', '000', 0, 104, 'no_lock_mgr', NULL, NULL)
(-104, 'HY', '000', 0, 105, 'ctxinuse', NULL, NULL)
(-104, 'HY', '000', 0, 106, 'ctxnotdef', NULL, NULL)
(-402, '42', '000', 0, 107, 'datnotsup', NULL, NULL)
(-901, 'HY', '000', 0, 108, 'badmsgnum', NULL, NULL)
(-104, 'HY', '000', 0, 109, 'badparnum', NULL, NULL)
(-904, 'HY', '001', 0, 110, 'virmemexh', NULL, NULL)
(-901, 'HY', '000', 0, 111, 'blocking_signal', NULL, NULL)
(-902, '40', '001', 0, 112, 'lockmanerr', NULL, NULL)
(-924, 'HY', '000', 0, 113, 'journerr', NULL, NULL)
(-664, '42', '000', 0, 114, 'keytoobig', NULL, NULL)
(-407, 'HY', '000', 0, 115, 'nullsegkey', NULL, NULL)
(-902, '00', '000', 0, 116, 'sqlerr', NULL, NULL)
(-820, 'HY', '000', 0, 117, 'wrodynver', NULL, NULL)
(-172, '39', '000', 0, 118, 'funnotdef', NULL, NULL)
(-171, '39', '000', 0, 119, 'funmismat', NULL, NULL)
(-104, '22', '001', 0, 120, 'bad_msg_vec', NULL, NULL)
(-924, '08', '007', 0, 121, 'bad_detach', NULL, NULL)
(-901, 'HY', '000', 0, 122, 'noargacc_read', NULL, NULL)
(-901, 'HY', '000', 0, 123, 'noargacc_write', NULL, NULL)
(-817, '42', '000', 0, 124, 'read_only', NULL, NULL)
(-677, '42', '000', 0, 125, 'ext_err', NULL, NULL)
(-150, '42', '000', 0, 126, 'non_updatable', NULL, NULL)
(-926, '25', 'S02', 0, 127, 'no_rollback', NULL, NULL)
(-902, 'HY', '000', 0, 128, 'bad_sec_info', NULL, NULL)
(-902, '28', '000', 0, 129, 'invalid_sec_info', NULL, NULL)
(-901, 'HY', '000', 0, 130, 'misc_interpreted', NULL, NULL)
(-904, '40', '001', 0, 131, 'update_conflict', NULL, NULL)
(-906, 'HY', '000', 0, 132, 'unlicensed', NULL, NULL)
(-904, '42', '000', 0, 133, 'obj_in_use', NULL, NULL)
(-413, 'HY', '000', 0, 134, 'nofilter', NULL, NULL)
(-904, '00', '000', 0, 135, 'shadow_accessed', NULL, NULL)
(-104, 'HY', '000', 0, 136, 'invalid_sdl', NULL, NULL)
(-406, '42', '000', 0, 137, 'out_of_bounds', NULL, NULL)
(-171, '42', '000', 0, 138, 'invalid_dimension', NULL, NULL)
(-911, 'HY', '000', 0, 139, 'rec_in_limbo', NULL, NULL)
(-904, 'HY', '000', 0, 140, 'shadow_missing', NULL, NULL)
(-923, 'HY', '000', 0, 141, 'cant_validate', NULL, NULL)
(-923, 'HY', '000', 0, 142, 'cant_start_journal', NULL, NULL)
(-204, '42', '000', 0, 143, 'gennotdef', NULL, NULL)
(-923, 'HY', '000', 0, 144, 'cant_start_logging', NULL, NULL)
(-685, '42', '000', 0, 145, 'bad_segstr_type', NULL, NULL)
(-530, '23', '000', 0, 146, 'foreign_key', NULL, NULL)
(-820, 'HY', '000', 0, 147, 'high_minor', NULL, NULL)
(-901, '00', '000', 0, 148, 'tra_state', NULL, NULL)
(-532, '25', '000', 0, 149, 'trans_invalid', NULL, NULL)
(-902, 'HY', '000', 0, 150, 'buf_invalid', NULL, NULL)
(-902, '42', 'S12', 0, 151, 'indexnotdefined', NULL, NULL)
(-902, '28', '000', 0, 152, 'login', NULL, NULL)
(-823, 'HY', '111', 0, 153, 'invalid_bookmark', NULL, NULL)
(-824, 'HY', '000', 0, 154, 'bad_lock_level', NULL, NULL)
(-615, '40', '001', 0, 155, 'relation_lock', NULL, NULL)
(-615, '40', '001', 0, 156, 'record_lock', NULL, NULL)
(-692, '54', '000', 0, 157, 'max_idx', NULL, NULL)
(-902, 'HY', '000', 0, 158, 'jrn_enable', NULL, NULL)
(-902, 'HY', '000', 0, 159, 'old_failure', NULL, NULL)
(-902, 'HY', '000', 0, 160, 'old_in_progress', NULL, NULL)
(-902, 'HY', '000', 0, 161, 'old_no_space', NULL, NULL)
(-902, 'HY', '000', 0, 162, 'no_wal_no_jrn', NULL, NULL)
(-902, 'HY', '000', 0, 163, 'num_old_files', NULL, NULL)
(-902, 'HY', '000', 0, 164, 'wal_file_open', NULL, NULL)
(-901, '26', '000', 0, 165, 'bad_stmt_handle', NULL, NULL)
(-902, 'HY', '000', 0, 166, 'wal_failure', NULL, NULL)
(-230, 'HY', '000', 0, 167, 'walw_err', NULL, NULL)
(-231, 'HY', '000', 0, 168, 'logh_small', NULL, NULL)
(-232, 'HY', '000', 0, 169, 'logh_inv_version', NULL, NULL)
(-233, 'HY', '000', 0, 170, 'logh_open_flag', NULL, NULL)
(-234, 'HY', '000', 0, 171, 'logh_open_flag2', NULL, NULL)
(-235, 'HY', '000', 0, 172, 'logh_diff_dbname', NULL, NULL)
(-236, 'HY', '000', 0, 173, 'logf_unexpected_eof', NULL, NULL)
(-237, 'HY', '000', 0, 174, 'logr_incomplete', NULL, NULL)
(-238, 'HY', '000', 0, 175, 'logr_header_small', NULL, NULL)
(-239, 'HY', '000', 0, 176, 'logb_small', NULL, NULL)
(-240, 'HY', '000', 0, 177, 'wal_illegal_attach', NULL, NULL)
(-241, 'HY', '000', 0, 178, 'wal_invalid_wpb', NULL, NULL)
(-242, 'HY', '000', 0, 179, 'wal_err_rollover', NULL, NULL)
(-243, 'HY', '000', 0, 180, 'no_wal', NULL, NULL)
(-615, 'HY', '000', 0, 181, 'drop_wal', NULL, NULL)
(-204, 'HY', '000', 0, 182, 'stream_not_defined', NULL, NULL)
(-244, 'HY', '000', 0, 183, 'wal_subsys_error', NULL, NULL)
(-245, 'XX', '000', 0, 184, 'wal_subsys_corrupt', NULL, NULL)
(-902, 'HY', '000', 0, 185, 'no_archive', NULL, NULL)
(-902, 'HY', '000', 0, 186, 'shutinprog', NULL, NULL)
(-615, '42', '000', 0, 187, 'range_in_use', NULL, NULL)
(-834, '42', '000', 0, 188, 'range_not_found', NULL, NULL)
(-204, '2C', '000', 0, 189, 'charset_not_found', NULL, NULL)
(-901, '40', '001', 0, 190, 'lock_timeout', NULL, NULL)
(-204, '42', '000', 0, 191, 'prcnotdef', NULL, NULL)
(-170, '07', '001', 0, 192, 'prcmismat', NULL, NULL)
(-246, 'XX', '000', 0, 193, 'wal_bugcheck', NULL, NULL)
(-247, 'HY', '000', 0, 194, 'wal_cant_expand', NULL, NULL)
(-204, 'HY', '000', 0, 195, 'codnotdef', NULL, NULL)
(-204, 'HY', '000', 0, 196, 'xcpnotdef', NULL, NULL)
(-836, 'HY', '000', 0, 197, 'except', NULL, NULL)
(-837, 'HY', '013', 0, 198, 'cache_restart', NULL, NULL)
(-825, 'HY', '000', 0, 199, 'bad_lock_handle', NULL, NULL)
(-902, 'HY', '000', 0, 200, 'jrn_present', NULL, NULL)
(-248, 'HY', '000', 0, 201, 'wal_err_rollover2', NULL, NULL)
(-249, 'HY', '000', 0, 202, 'wal_err_logwrite', NULL, NULL)
(-250, 'HY', '000', 0, 203, 'wal_err_jrn_comm', NULL, NULL)
(-251, 'HY', '000', 0, 204, 'wal_err_expansion', NULL, NULL)
(-252, 'HY', '000', 0, 205, 'wal_err_setup', NULL, NULL)
(-253, 'HY', '000', 0, 206, 'wal_err_ww_sync', NULL, NULL)
(-254, 'HY', '000', 0, 207, 'wal_err_ww_start', NULL, NULL)
(-902, 'HY', '000', 0, 208, 'shutdown', NULL, NULL)
(-553, '28', '000', 0, 209, 'existing_priv_mod', NULL, NULL)
(-616, '42', '000', 0, 210, 'primary_key_ref', NULL, NULL)
(-291, '42', '000', 0, 211, 'primary_key_notnull', NULL, NULL)
(-204, '42', '000', 0, 212, 'ref_cnstrnt_notfound', NULL, NULL)
(-660, '42', '000', 0, 213, 'foreign_key_notfound', NULL, NULL)
(-292, '42', '000', 0, 214, 'ref_cnstrnt_update', NULL, NULL)
(-293, '44', '000', 0, 215, 'check_cnstrnt_update', NULL, NULL)
(-294, '44', '000', 0, 216, 'check_cnstrnt_del', NULL, NULL)
(-618, '42', '000', 0, 217, 'integ_index_seg_del', NULL, NULL)
(-618, '42', '000', 0, 218, 'integ_index_seg_mod', NULL, NULL)
(-616, '42', '000', 0, 219, 'integ_index_del', NULL, NULL)
(-616, '42', '000', 0, 220, 'integ_index_mod', NULL, NULL)
(-616, '44', '000', 0, 221, 'check_trig_del', NULL, NULL)
(-617, '44', '000', 0, 222, 'check_trig_update', NULL, NULL)
(-616, '23', '000', 0, 223, 'cnstrnt_fld_del', NULL, NULL)
(-617, '23', '000', 0, 224, 'cnstrnt_fld_rename', NULL, NULL)
(-295, '42', '000', 0, 225, 'rel_cnstrnt_update', NULL, NULL)
(-150, '42', '000', 0, 226, 'constaint_on_view', NULL, NULL)
(-296, '42', '000', 0, 227, 'invld_cnstrnt_type', NULL, NULL)
(-831, '42', 'S11', 0, 228, 'primary_key_exists', NULL, NULL)
(-607, 'HY', '000', 0, 229, 'systrig_update', NULL, NULL)
(-552, '28', '000', 0, 230, 'not_rel_owner', NULL, NULL)
(-204, '01', '007', 0, 231, 'grant_obj_notfound', NULL, NULL)
(-205, '01', '007', 0, 232, 'grant_fld_notfound', NULL, NULL)
(-552, '01', '007', 0, 233, 'grant_nopriv', NULL, NULL)
(-84, '28', '000', 0, 234, 'nonsql_security_rel', NULL, NULL)
(-84, '28', '000', 0, 235, 'nonsql_security_fld', NULL, NULL)
(-255, 'HY', '000', 0, 236, 'wal_cache_err', NULL, NULL)
(-902, 'HY', '000', 0, 237, 'shutfail', NULL, NULL)
(-297, '23', '000', 0, 238, 'check_constraint', NULL, NULL)
(-901, 'HY', '000', 0, 239, 'bad_svc_handle', NULL, NULL)
(-838, 'HY', '000', 0, 240, 'shutwarn', NULL, NULL)
(-901, 'HY', '000', 0, 241, 'wrospbver', NULL, NULL)
(-901, '42', '000', 0, 242, 'bad_spb_form', NULL, NULL)
(-901, 'HY', '000', 0, 243, 'svcnotdef', NULL, NULL)
(-902, 'HY', '000', 0, 244, 'no_jrn', NULL, NULL)
(-314, '22', '018', 0, 245, 'transliteration_failed', NULL, NULL)
(-257, 'HY', '000', 0, 246, 'start_cm_for_wal', NULL, NULL)
(-258, 'HY', '000', 0, 247, 'wal_ovflow_log_required', NULL, NULL)
(-204, '42', '000', 0, 248, 'text_subtype', NULL, NULL)
(-902, '42', '000', 0, 249, 'dsql_error', NULL, NULL)
(-104, '42', '000', 0, 250, 'dsql_command_err', NULL, NULL)
(-103, 'HY', '004', 0, 251, 'dsql_constant_err', NULL, NULL)
(-504, 'HY', '015', 0, 252, 'dsql_cursor_err', NULL, NULL)
(-204, 'HY', '004', 0, 253, 'dsql_datatype_err', NULL, NULL)
(-502, '34', '000', 0, 254, 'dsql_decl_err', NULL, NULL)
(-510, '24', '000', 0, 255, 'dsql_cursor_update_err', NULL, NULL)
(-502, '24', '000', 0, 256, 'dsql_cursor_open_err', NULL, NULL)
(-501, '24', '000', 0, 257, 'dsql_cursor_close_err', NULL, NULL)
(-206, '42', 'S22', 0, 258, 'dsql_field_err', NULL, NULL)
(-104, 'XX', '000', 0, 259, 'dsql_internal_err', NULL, NULL)
(-204, '42', 'S02', 0, 260, 'dsql_relation_err', NULL, NULL)
(-204, '42', '000', 0, 261, 'dsql_procedure_err', NULL, NULL)
(-518, '42', '000', 0, 262, 'dsql_request_err', NULL, NULL)
(-804, '07', '002', 0, 263, 'dsql_sqlda_err', NULL, NULL)
(-804, '21', 'S01', 0, 264, 'dsql_var_count_err', NULL, NULL)
(-826, 'HY', '000', 0, 265, 'dsql_stmt_handle', NULL, NULL)
(-804, '39', '000', 0, 266, 'dsql_function_err', NULL, NULL)
(-206, '42', '000', 0, 267, 'dsql_blob_err', NULL, NULL)
(-204, '22', '021', 0, 268, 'collation_not_found', NULL, NULL)
(-204, '22', '021', 0, 269, 'collation_not_for_charset', NULL, NULL)
(-104, '42', '000', 0, 270, 'dsql_dup_option', NULL, NULL)
(-104, '25', '000', 0, 271, 'dsql_tran_err', NULL, NULL)
(-104, 'HY', '000', 0, 272, 'dsql_invalid_array', NULL, NULL)
(-604, '54', '000', 0, 273, 'dsql_max_arr_dim_exceeded', NULL, NULL)
(-604, '42', '000', 0, 274, 'dsql_arr_range_error', NULL, NULL)
(-204, 'HY', '000', 0, 275, 'dsql_trigger_err', NULL, NULL)
(-206, '42', '000', 0, 276, 'dsql_subselect_err', NULL, NULL)
(-531, '42', '000', 0, 277, 'dsql_crdb_prepare_err', NULL, NULL)
(-157, '42', '000', 0, 278, 'specify_field_err', NULL, NULL)
(-158, '07', '002', 0, 279, 'num_field_err', NULL, NULL)
(-806, '42', '000', 0, 280, 'col_name_err', NULL, NULL)
(-807, '42', '000', 0, 281, 'where_err', NULL, NULL)
(-808, '42', '000', 0, 282, 'table_view_err', NULL, NULL)
(-809, '42', '000', 0, 283, 'distinct_err', NULL, NULL)
(-832, '42', '000', 0, 284, 'key_field_count_err', NULL, NULL)
(-810, '42', '000', 0, 285, 'subquery_err', NULL, NULL)
(-833, '42', '000', 0, 286, 'expression_eval_err', NULL, NULL)
(-599, 'HY', '000', 0, 287, 'node_err', NULL, NULL)
(-104, '42', '000', 0, 288, 'command_end_err', NULL, NULL)
(-901, '42', '000', 0, 289, 'index_name', NULL, NULL)
(-901, '22', '000', 0, 290, 'exception_name', NULL, NULL)
(-901, '42', '000', 0, 291, 'field_name', NULL, NULL)
(-104, '42', '000', 0, 292, 'token_err', NULL, NULL)
(-901, '42', '000', 0, 293, 'union_err', NULL, NULL)
(-901, '42', '000', 0, 294, 'dsql_construct_err', NULL, NULL)
(-830, '42', '000', 0, 295, 'field_aggregate_err', NULL, NULL)
(-829, '42', 'S22', 0, 296, 'field_ref_err', NULL, NULL)
(-208, '42', '000', 0, 297, 'order_by_err', NULL, NULL)
(-171, 'HY', '000', 0, 298, 'return_mode_err', NULL, NULL)
(-170, '38', '000', 0, 299, 'extern_func_err', NULL, NULL)
(-204, '08', '001', 0, 300, 'alias_conflict_err', NULL, NULL)
(-204, '42', '000', 0, 301, 'procedure_conflict_error', NULL, NULL)
(-204, '42', '000', 0, 302, 'relation_conflict_err', NULL, NULL)
(-901, '42', '000', 0, 303, 'dsql_domain_err', NULL, NULL)
(-663, '42', '000', 0, 304, 'idx_seg_err', NULL, NULL)
(-599, 'HY', '000', 0, 305, 'node_name_err', NULL, NULL)
(-901, '00', '000', 0, 306, 'table_name', NULL, NULL)
(-901, '42', '000', 0, 307, 'proc_name', NULL, NULL)
(-660, '42', '000', 0, 308, 'idx_create_err', NULL, NULL)
(-259, 'HY', '000', 0, 309, 'wal_shadow_err', NULL, NULL)
(-616, '42', '000', 0, 310, 'dependency', NULL, NULL)
(-663, '54', '011', 0, 311, 'idx_key_err', NULL, NULL)
(-597, '42', '000', 0, 312, 'dsql_file_length_err', NULL, NULL)
(-598, 'HY', '000', 0, 313, 'dsql_shadow_number_err', NULL, NULL)
(-104, '42', '000', 0, 314, 'dsql_token_unk_err', NULL, NULL)
(-204, '42', 'S02', 0, 315, 'dsql_no_relation_alias', NULL, NULL)
(-204, '42', '000', 0, 316, 'indexname', NULL, NULL)
(-281, 'HY', '000', 0, 317, 'no_stream_plan', NULL, NULL)
(-282, 'HY', '000', 0, 318, 'stream_twice', NULL, NULL)
(-283, 'HY', '000', 0, 319, 'stream_not_found', NULL, NULL)
(-204, '22', '021', 0, 320, 'collation_requires_text', NULL, NULL)
(-901, '42', '000', 0, 321, 'dsql_domain_not_found', NULL, NULL)
(-284, '42', '000', 0, 322, 'index_unused', NULL, NULL)
(-282, '42', '000', 0, 323, 'dsql_self_join', NULL, NULL)
(-596, 'HY', '109', 0, 324, 'stream_bof', NULL, NULL)
(-595, 'HY', '000', 0, 325, 'stream_crack', NULL, NULL)
(-601, 'HY', '000', 0, 326, 'db_or_file_exists', NULL, NULL)
(-401, '42', '000', 0, 327, 'invalid_operator', NULL, NULL)
(-924, 'HY', '000', 0, 328, 'conn_lost', NULL, NULL)
(-835, '42', '000', 0, 329, 'bad_checksum', NULL, NULL)
(-689, 'HY', '000', 0, 330, 'page_type_err', NULL, NULL)
(-816, '42', '000', 0, 331, 'ext_readonly_err', NULL, NULL)
(-811, '21', '000', 0, 332, 'sing_select_err', NULL, NULL)
(-902, '28', '000', 0, 333, 'psw_attach', NULL, NULL)
(-902, '28', '000', 0, 334, 'psw_start_trans', NULL, NULL)
(-827, '42', '000', 0, 335, 'invalid_direction', NULL, NULL)
(-901, 'HY', '000', 0, 336, 'dsql_var_conflict', NULL, NULL)
(-607, 'HY', '000', 0, 337, 'dsql_no_blob_array', NULL, NULL)
(-155, '42', '000', 0, 338, 'dsql_base_table', NULL, NULL)
(-282, '42', '000', 0, 339, 'duplicate_base_table', NULL, NULL)
(-282, '42', '000', 0, 340, 'view_alias', NULL, NULL)
(-904, '54', '000', 0, 341, 'index_root_page_full', NULL, NULL)
(-204, '42', '000', 0, 342, 'dsql_blob_type_unknown', NULL, NULL)
(-693, '54', '001', 0, 343, 'req_max_clones_exceeded', NULL, NULL)
(-637, '42', '000', 0, 344, 'dsql_duplicate_spec', NULL, NULL)
(-803, '23', '000', 0, 345, 'unique_key_violation', NULL, NULL)
(-901, 'HY', '000', 0, 346, 'srvr_version_too_old', NULL, NULL)
(-909, 'HY', '000', 0, 347, 'drdb_completed_with_errs', NULL, NULL)
(-84, '42', '000', 0, 348, 'dsql_procedure_use_err', NULL, NULL)
(-313, '07', '002', 0, 349, 'dsql_count_mismatch', NULL, NULL)
(-685, '42', '000', 0, 350, 'blob_idx_err', NULL, NULL)
(-685, '42', '000', 0, 351, 'array_idx_err', NULL, NULL)
(-663, '42', '000', 0, 352, 'key_field_err', NULL, NULL)
(-901, 'HY', '000', 0, 353, 'no_delete', NULL, NULL)
(-616, '42', '000', 0, 354, 'del_last_field', NULL, NULL)
(-901, 'HY', '000', 0, 355, 'sort_err', NULL, NULL)
(-904, 'HY', '001', 0, 356, 'sort_mem_err', NULL, NULL)
(-841, '54', '000', 0, 357, 'version_err', NULL, NULL)
(-828, 'HY', '000', 0, 358, 'inval_key_posn', NULL, NULL)
(-690, 'HY', '000', 0, 359, 'no_segments_err', NULL, NULL)
(-600, 'XX', '000', 0, 360, 'crrp_data_err', NULL, NULL)
(-691, '54', '000', 0, 361, 'rec_size_err', NULL, NULL)
(-605, '42', '000', 0, 362, 'dsql_field_ref', NULL, NULL)
(-904, '54', '001', 0, 363, 'req_depth_exceeded', NULL, NULL)
(-694, '42', 'S22', 0, 364, 'no_field_access', NULL, NULL)
(-162, 'HY', '000', 0, 365, 'no_dbkey', NULL, NULL)
(-839, 'HY', '000', 0, 366, 'jrn_format_err', NULL, NULL)
(-840, 'HY', '000', 0, 367, 'jrn_file_full', NULL, NULL)
(-519, '24', '000', 0, 368, 'dsql_open_cursor_request', NULL, NULL)
(-999, 'HY', '000', 0, 369, 'ib_error', NULL, NULL)
(-260, 'HY', '013', 0, 370, 'cache_redef', NULL, NULL)
(-239, 'HY', '013', 0, 371, 'cache_too_small', NULL, NULL)
(-260, 'HY', '000', 0, 372, 'log_redef', NULL, NULL)
(-239, 'HY', '000', 0, 373, 'log_too_small', NULL, NULL)
(-239, 'HY', '000', 0, 374, 'partition_too_small', NULL, NULL)
(-261, 'HY', '000', 0, 375, 'partition_not_supp', NULL, NULL)
(-261, 'HY', '000', 0, 376, 'log_length_spec', NULL, NULL)
(-842, 'HY', '104', 0, 377, 'precision_err', NULL, NULL)
(-842, 'HY', '104', 0, 378, 'scale_nogt', NULL, NULL)
(-842, '22', '003', 0, 379, 'expec_short', NULL, NULL)
(-842, '22', '003', 0, 380, 'expec_long', NULL, NULL)
(-842, '22', '003', 0, 381, 'expec_ushort', NULL, NULL)
(-105, '22', '025', 0, 382, 'escape_invalid', NULL, NULL)
(-901, 'HY', '000', 0, 383, 'svcnoexe', NULL, NULL)
(-901, '08', '006', 0, 384, 'net_lookup_err', NULL, NULL)
(-901, 'HY', '000', 0, 385, 'service_unknown', NULL, NULL)
(-901, '08', '001', 0, 386, 'host_unknown', NULL, NULL)
(-552, '01', '007', 0, 387, 'grant_nopriv_on_base', NULL, NULL)
(-203, '42', '702', 0, 388, 'dyn_fld_ambiguous', NULL, NULL)
(-104, '42', '000', 0, 389, 'dsql_agg_ref_err', NULL, NULL)
(-282, 'HY', '000', 0, 390, 'complex_view', NULL, NULL)
(-901, 'HY', '007', 0, 391, 'unprepared_stmt', NULL, NULL)
(-842, '42', '000', 0, 392, 'expec_positive', NULL, NULL)
(-804, 'HY', '000', 0, 393, 'dsql_sqlda_value_err', NULL, NULL)
(-104, 'HY', '000', 0, 394, 'invalid_array_id', NULL, NULL)
(-816, '42', '000', 0, 395, 'extfile_uns_op', NULL, NULL)
(-901, 'HY', '000', 0, 396, 'svc_in_use', NULL, NULL)
(-902, 'HY', '013', 0, 397, 'err_stack_limit', NULL, NULL)
(-827, '42', '000', 0, 398, 'invalid_key', NULL, NULL)
(-901, '08', '006', 0, 399, 'net_init_error', NULL, NULL)
(-901, 'HY', '000', 0, 400, 'loadlib_failure', NULL, NULL)
(-902, '08', '006', 0, 401, 'network_error', NULL, NULL)
(-902, '08', '006', 0, 402, 'net_connect_err', NULL, NULL)
(-902, '08', '006', 0, 403, 'net_connect_listen_err', NULL, NULL)
(-902, '08', '006', 0, 404, 'net_event_connect_err', NULL, NULL)
(-902, '08', '006', 0, 405, 'net_event_listen_err', NULL, NULL)
(-902, '08', '006', 0, 406, 'net_read_err', NULL, NULL)
(-902, '08', '006', 0, 407, 'net_write_err', NULL, NULL)
(-616, '42', '000', 0, 408, 'integ_index_deactivate', NULL, NULL)
(-616, '42', '000', 0, 409, 'integ_deactivate_primary', NULL, NULL)
(-104, 'HY', '000', 0, 410, 'cse_not_supported', NULL, NULL)
(-901, 'HY', '000', 0, 411, 'tra_must_sweep', NULL, NULL)
(-902, 'HY', '000', 0, 412, 'unsupported_network_drive', NULL, NULL)
(-902, '08', '001', 0, 413, 'io_create_err', NULL, NULL)
(-902, '08', '001', 0, 414, 'io_open_err', NULL, NULL)
(-902, 'HY', '000', 0, 415, 'io_close_err', NULL, NULL)
(-902, 'HY', '000', 0, 416, 'io_read_err', NULL, NULL)
(-902, 'HY', '000', 0, 417, 'io_write_err', NULL, NULL)
(-902, 'HY', '000', 0, 418, 'io_delete_err', NULL, NULL)
(-902, 'HY', '000', 0, 419, 'io_access_err', NULL, NULL)
(-901, '38', '000', 0, 420, 'udf_exception', NULL, NULL)
(-901, '08', '006', 0, 421, 'lost_db_connection', NULL, NULL)
(-901, '28', '000', 0, 422, 'no_write_user_priv', NULL, NULL)
(-104, '42', '000', 0, 423, 'token_too_long', NULL, NULL)
(-906, '08', '001', 0, 424, 'max_att_exceeded', NULL, NULL)
(-902, '28', '000', 0, 425, 'login_same_as_role_name', NULL, NULL)
(-607, '42', '000', 0, 426, 'reftable_requires_pk', NULL, NULL)
(-85, '28', '000', 0, 427, 'usrname_too_long', NULL, NULL)
(-85, '28', '000', 0, 428, 'password_too_long', NULL, NULL)
(-85, '28', '000', 0, 429, 'usrname_required', NULL, NULL)
(-85, '28', '000', 0, 430, 'password_required', NULL, NULL)
(-85, '42', '000', 0, 431, 'bad_protocol', NULL, NULL)
(-85, '28', '000', 0, 432, 'dup_usrname_found', NULL, NULL)
(-85, '28', '000', 0, 433, 'usrname_not_found', NULL, NULL)
(-85, '28', '000', 0, 434, 'error_adding_sec_record', NULL, NULL)
(-85, '28', '000', 0, 435, 'error_modifying_sec_record', NULL, NULL)
(-85, '28', '000', 0, 436, 'error_deleting_sec_record', NULL, NULL)
(-85, '28', '000', 0, 437, 'error_updating_sec_db', NULL, NULL)
(-904, 'HY', '000', 0, 438, 'sort_rec_size_err', NULL, NULL)
(-204, '42', '000', 0, 439, 'bad_default_value', NULL, NULL)
(-204, '42', '000', 0, 440, 'invalid_clause', NULL, NULL)
(-904, 'HY', '000', 0, 441, 'too_many_handles', NULL, NULL)
(-904, 'HY', '000', 0, 442, 'optimizer_blk_exc', NULL, NULL)
(-104, '42', '000', 0, 443, 'invalid_string_constant', NULL, NULL)
(-104, 'HY', '000', 0, 444, 'transitional_date', NULL, NULL)
(-817, '42', '000', 0, 445, 'read_only_database', NULL, NULL)
(-817, 'HY', '000', 0, 446, 'must_be_dialect_2_and_up', NULL, NULL)
(-901, 'HY', '000', 0, 447, 'blob_filter_exception', NULL, NULL)
(-901, 'HY', '000', 0, 448, 'exception_access_violation', NULL, NULL)
(-901, '22', '000', 0, 449, 'exception_datatype_missalignment', NULL, NULL)
(-901, '22', '000', 0, 450, 'exception_array_bounds_exceeded', NULL, NULL)
(-901, '22', '000', 0, 451, 'exception_float_denormal_operand', NULL, NULL)
(-901, '22', '012', 0, 452, 'exception_float_divide_by_zero', NULL, NULL)
(-901, '22', '000', 0, 453, 'exception_float_inexact_result', NULL, NULL)
(-901, '22', '000', 0, 454, 'exception_float_invalid_operand', NULL, NULL)
(-901, '22', '003', 0, 455, 'exception_float_overflow', NULL, NULL)
(-901, '22', '000', 0, 456, 'exception_float_stack_check', NULL, NULL)
(-901, '22', '003', 0, 457, 'exception_float_underflow', NULL, NULL)
(-901, '22', '012', 0, 458, 'exception_integer_divide_by_zero', NULL, NULL)
(-901, '22', '003', 0, 459, 'exception_integer_overflow', NULL, NULL)
(-901, 'HY', '000', 0, 460, 'exception_unknown', NULL, NULL)
(-901, 'HY', '001', 0, 461, 'exception_stack_overflow', NULL, NULL)
(-901, 'HY', '000', 0, 462, 'exception_sigsegv', NULL, NULL)
(-901, 'HY', '000', 0, 463, 'exception_sigill', NULL, NULL)
(-901, 'HY', '000', 0, 464, 'exception_sigbus', NULL, NULL)
(-901, 'HY', '000', 0, 465, 'exception_sigfpe', NULL, NULL)
(-901, '42', '000', 0, 466, 'ext_file_delete', NULL, NULL)
(-901, '42', '000', 0, 467, 'ext_file_modify', NULL, NULL)
(-901, '28', '000', 0, 468, 'adm_task_denied', NULL, NULL)
(-105, '42', '000', 0, 469, 'extract_input_mismatch', NULL, NULL)
(-551, '28', '000', 0, 470, 'insufficient_svc_privileges', NULL, NULL)
(-902, 'HY', '000', 0, 471, 'file_in_use', NULL, NULL)
(-904, 'HY', '000', 0, 472, 'service_att_err', NULL, NULL)
(-817, '42', '000', 0, 473, 'ddl_not_allowed_by_db_sql_dial', NULL, NULL)
(-901, 'HY', '008', 0, 474, 'cancelled', NULL, NULL)
(-902, 'HY', '000', 0, 475, 'unexp_spb_form', NULL, NULL)
(-104, 'HY', '000', 0, 476, 'sql_dialect_datatype_unsupport', NULL, NULL)
(-901, 'HY', '000', 0, 477, 'svcnouser', NULL, NULL)
(-104, '42', '000', 0, 478, 'depend_on_uncommitted_rel', NULL, NULL)
(-904, 'HY', '000', 0, 479, 'svc_name_missing', NULL, NULL)
(-204, '54', '001', 0, 480, 'too_many_contexts', NULL, NULL)
(-901, '22', '008', 0, 481, 'datype_notsup', NULL, NULL)
(501, '01', '000', 0, 482, 'dialect_reset_warning', NULL, NULL)
(-901, 'HY', '000', 0, 483, 'dialect_not_changed', NULL, NULL)
(-901, 'HY', '000', 0, 484, 'database_create_failed', NULL, NULL)
(-901, '42', '000', 0, 485, 'inv_dialect_specified', NULL, NULL)
(-901, '00', '000', 0, 486, 'valid_db_dialects', NULL, NULL)
(300, '00', '000', 0, 487, 'sqlwarn', NULL, NULL)
(301, 'HY', '000', 0, 488, 'dtype_renamed', NULL, NULL)
(-902, '38', '000', 0, 489, 'extern_func_dir_error', NULL, NULL)
(-833, '22', '008', 0, 490, 'date_range_exceeded', NULL, NULL)
(-901, '42', '000', 0, 491, 'inv_client_dialect_specified', NULL, NULL)
(-901, '00', '000', 0, 492, 'valid_client_dialects', NULL, NULL)
(-904, 'HY', '004', 0, 493, 'optimizer_between_err', NULL, NULL)
(-901, 'HY', '000', 0, 494, 'service_not_supported', NULL, NULL)
(-607, '00', '000', 0, 495, 'generator_name', NULL, NULL)
(-607, '38', '000', 0, 496, 'udf_name', NULL, NULL)
(-204, 'HY', '000', 0, 497, 'bad_limit_param', NULL, NULL)
(-204, '42', '000', 0, 498, 'bad_skip_param', NULL, NULL)
(-902, '54', '000', 0, 499, 'io_32bit_exceeded_err', NULL, NULL)
(-901, '3B', '000', 0, 500, 'invalid_savepoint', NULL, NULL)
(-104, '42', '000', 0, 501, 'dsql_column_pos_err', NULL, NULL)
(-104, '42', '000', 0, 502, 'dsql_agg_where_err', NULL, NULL)
(-104, '42', '000', 0, 503, 'dsql_agg_group_err', NULL, NULL)
(-104, '42', '000', 0, 504, 'dsql_agg_column_err', NULL, NULL)
(-104, '42', '000', 0, 505, 'dsql_agg_having_err', NULL, NULL)
(-104, '42', '000', 0, 506, 'dsql_agg_nested_err', NULL, NULL)
(-904, '42', '000', 0, 507, 'exec_sql_invalid_arg', NULL, NULL)
(-904, '42', '000', 0, 508, 'exec_sql_invalid_req', NULL, NULL)
(-904, '42', '000', 0, 509, 'exec_sql_invalid_var', NULL, NULL)
(-904, '42', '000', 0, 510, 'exec_sql_max_call_exceeded', NULL, NULL)
(-902, '28', '000', 0, 511, 'conf_access_denied', NULL, NULL)
(-904, 'HY', '000', 0, 512, 'wrong_backup_state', NULL, NULL)
(-904, 'HY', '000', 0, 513, 'wal_backup_err', NULL, NULL)
(-902, '24', '000', 0, 514, 'cursor_not_open', NULL, NULL)
(-901, '08', '007', 0, 515, 'bad_shutdown_mode', NULL, NULL)
(-802, 'HY', '000', 0, 516, 'concat_overflow', NULL, NULL)
(-204, '22', '011', 0, 517, 'bad_substring_offset', NULL, NULL)
(-530, '42', '000', 0, 518, 'foreign_key_target_doesnt_exist', NULL, NULL)
(-530, '42', '000', 0, 519, 'foreign_key_references_present', NULL, NULL)
(-901, 'HY', '000', 0, 520, 'no_update', NULL, NULL)
(-902, '24', '000', 0, 521, 'cursor_already_open', NULL, NULL)
(-901, '00', '000', 0, 522, 'stack_trace', NULL, NULL)
(-901, 'HY', '000', 0, 523, 'ctx_var_not_found', NULL, NULL)
(-901, 'HY', '000', 0, 524, 'ctx_namespace_invalid', NULL, NULL)
(-901, '54', '000', 0, 525, 'ctx_too_big', NULL, NULL)
(-901, 'HY', '000', 0, 526, 'ctx_bad_argument', NULL, NULL)
(-901, '42', '000', 0, 527, 'identifier_too_long', NULL, NULL)
(-836, 'HY', '000', 0, 528, 'except2', NULL, NULL)
(-104, '22', '000', 0, 529, 'malformed_string', NULL, NULL)
(-170, '07', '002', 0, 530, 'prc_out_param_mismatch', NULL, NULL)
(-104, '42', '000', 0, 531, 'command_end_err2', NULL, NULL)
(-904, '42', '000', 0, 532, 'partner_idx_incompat_type', NULL, NULL)
(-204, '22', '011', 0, 533, 'bad_substring_length', NULL, NULL)
(-204, '2C', '000', 0, 534, 'charset_not_installed', NULL, NULL)
(-204, '22', '021', 0, 535, 'collation_not_installed', NULL, NULL)
(-902, '08', '003', 0, 536, 'att_shutdown', NULL, NULL)
(-904, '54', '000', 0, 537, 'blobtoobig', NULL, NULL)
(-607, '42', '000', 0, 538, 'must_have_phys_field', NULL, NULL)
(-901, '22', '007', 0, 539, 'invalid_time_precision', NULL, NULL)
(-413, 'HY', '000', 0, 540, 'blob_convert_error', NULL, NULL)
(-413, '22', '000', 0, 541, 'array_convert_error', NULL, NULL)
(-904, '40', '001', 0, 542, 'record_lock_not_supp', NULL, NULL)
(-904, '42', '000', 0, 543, 'partner_idx_not_found', NULL, NULL)
(-904, '54', '000', 0, 544, 'tra_num_exc', NULL, NULL)
(-904, '42', '000', 0, 545, 'field_disappeared', NULL, NULL)
(-901, 'HY', '000', 0, 546, 'met_wrong_gtt_scope', NULL, NULL)
(-204, 'HY', '000', 0, 547, 'subtype_for_internal_use', NULL, NULL)
(-901, '42', '000', 0, 548, 'illegal_prc_type', NULL, NULL)
(-901, '42', '000', 0, 549, 'invalid_sort_datatype', NULL, NULL)
(-901, '00', '000', 0, 550, 'collation_name', NULL, NULL)
(-901, '00', '000', 0, 551, 'domain_name', NULL, NULL)
(-219, '42', '000', 0, 552, 'domnotdef', NULL, NULL)
(-171, '54', '000', 0, 553, 'array_max_dimensions', NULL, NULL)
(-901, '54', '000', 0, 554, 'max_db_per_trans_allowed', NULL, NULL)
(0, '00', '000', 0, 555, 'bad_debug_format', NULL, NULL)
(-901, '2F', '000', 0, 556, 'bad_proc_BLR', NULL, NULL)
(-901, '54', '000', 0, 557, 'key_too_big', NULL, NULL)
(-904, 'HY', '000', 0, 558, 'concurrent_transaction', NULL, NULL)
(-625, '42', '000', 0, 559, 'not_valid_for_var', NULL, NULL)
(-625, '42', '000', 0, 560, 'not_valid_for', NULL, NULL)
(-820, 'HY', '000', 0, 561, 'need_difference', NULL, NULL)
(-902, 'HY', '000', 0, 562, 'long_login', NULL, NULL)
(-205, '42', 'S22', 0, 563, 'fldnotdef2', NULL, NULL)
(-105, '42', '000', 0, 564, 'invalid_similar_pattern', NULL, NULL)
(-901, 'HY', '000', 0, 565, 'bad_teb_form', NULL, NULL)
(-901, 'HY', '000', 0, 566, 'tpb_multiple_txn_isolation', NULL, NULL)
(-901, 'HY', '000', 0, 567, 'tpb_reserv_before_table', NULL, NULL)
(-901, 'HY', '000', 0, 568, 'tpb_multiple_spec', NULL, NULL)
(-901, 'HY', '000', 0, 569, 'tpb_option_without_rc', NULL, NULL)
(-901, 'HY', '000', 0, 570, 'tpb_conflicting_options', NULL, NULL)
(-901, 'HY', '000', 0, 571, 'tpb_reserv_missing_tlen', NULL, NULL)
(-901, 'HY', '000', 0, 572, 'tpb_reserv_long_tlen', NULL, NULL)
(-901, 'HY', '000', 0, 573, 'tpb_reserv_missing_tname', NULL, NULL)
(-901, 'HY', '000', 0, 574, 'tpb_reserv_corrup_tlen', NULL, NULL)
(-901, 'HY', '000', 0, 575, 'tpb_reserv_null_tlen', NULL, NULL)
(-901, 'HY', '000', 0, 576, 'tpb_reserv_relnotfound', NULL, NULL)
(-901, 'HY', '000', 0, 577, 'tpb_reserv_baserelnotfound', NULL, NULL)
(-901, 'HY', '000', 0, 578, 'tpb_missing_len', NULL, NULL)
(-901, 'HY', '000', 0, 579, 'tpb_missing_value', NULL, NULL)
(-901, 'HY', '000', 0, 580, 'tpb_corrupt_len', NULL, NULL)
(-901, 'HY', '000', 0, 581, 'tpb_null_len', NULL, NULL)
(-901, 'HY', '000', 0, 582, 'tpb_overflow_len', NULL, NULL)
(-901, 'HY', '000', 0, 583, 'tpb_invalid_value', NULL, NULL)
(-901, 'HY', '000', 0, 584, 'tpb_reserv_stronger_wng', NULL, NULL)
(-901, 'HY', '000', 0, 585, 'tpb_reserv_stronger', NULL, NULL)
(-901, 'HY', '000', 0, 586, 'tpb_reserv_max_recursion', NULL, NULL)
(-901, 'HY', '000', 0, 587, 'tpb_reserv_virtualtbl', NULL, NULL)
(-901, 'HY', '000', 0, 588, 'tpb_reserv_systbl', NULL, NULL)
(-901, 'HY', '000', 0, 589, 'tpb_reserv_temptbl', NULL, NULL)
(-901, 'HY', '000', 0, 590, 'tpb_readtxn_after_writelock', NULL, NULL)
(-901, 'HY', '000', 0, 591, 'tpb_writelock_after_readtxn', NULL, NULL)
(-833, '22', '008', 0, 592, 'time_range_exceeded', NULL, NULL)
(-833, '22', '008', 0, 593, 'datetime_range_exceeded', NULL, NULL)
(-802, '22', '001', 0, 594, 'string_truncation', NULL, NULL)
(-802, '22', '001', 0, 595, 'blob_truncation', NULL, NULL)
(-802, '22', '003', 0, 596, 'numeric_out_of_range', NULL, NULL)
(-901, 'HY', 'T00', 0, 597, 'shutdown_timeout', NULL, NULL)
(-901, 'HY', '010', 0, 598, 'att_handle_busy', NULL, NULL)
(-901, '39', '000', 0, 599, 'bad_udf_freeit', NULL, NULL)
(-901, '42', '000', 0, 600, 'eds_provider_not_found', NULL, NULL)
(-901, '42', '000', 0, 601, 'eds_connection', NULL, NULL)
(-901, '42', '000', 0, 602, 'eds_preprocess', NULL, NULL)
(-901, '42', '000', 0, 603, 'eds_stmt_expected', NULL, NULL)
(-901, '42', '000', 0, 604, 'eds_prm_name_expected', NULL, NULL)
(-901, '42', '000', 0, 605, 'eds_unclosed_comment', NULL, NULL)
(-901, '42', '000', 0, 606, 'eds_statement', NULL, NULL)
(-901, '42', '000', 0, 607, 'eds_input_prm_mismatch', NULL, NULL)
(-901, '42', '000', 0, 608, 'eds_output_prm_mismatch', NULL, NULL)
(-901, '42', '000', 0, 609, 'eds_input_prm_not_set', NULL, NULL)
(-104, 'HY', '000', 0, 610, 'too_big_blr', NULL, NULL)
(-000, 'HY', '001', 0, 611, 'montabexh', NULL, NULL)
(-172, '39', '000', 0, 612, 'modnotfound', NULL, NULL)
(-901, 'HY', '018', 0, 613, 'nothing_to_cancel', NULL, NULL)
(-901, '39', '000', 0, 614, 'ibutil_not_loaded', NULL, NULL)
(-904, '42', '000', 0, 615, 'circular_computed', NULL, NULL)
(-902, '28', '000', 0, 616, 'psw_db_error', NULL, NULL)
-- For the following values I simply copied the error code and SQL codes from expression_eval_err
(-833, '42', '000', 0, 617, 'invalid_type_datetime_op', NULL, NULL)
(-833, '42', '000', 0, 618, 'onlycan_add_timetodate', NULL, NULL)
(-833, '42', '000', 0, 619, 'onlycan_add_datetotime', NULL, NULL)
(-833, '42', '000', 0, 620, 'onlycansub_tstampfromtstamp', NULL, NULL)
(-833, '42', '000', 0, 621, 'onlyoneop_mustbe_tstamp', NULL, NULL)
(-833, '42', '000', 0, 622, 'invalid_extractpart_time', NULL, NULL)
(-833, '42', '000', 0, 623, 'invalid_extractpart_date', NULL, NULL)
(-833, '42', '000', 0, 624, 'invalidarg_extract', NULL, NULL)
(-833, '42', '000', 0, 625, 'sysf_argmustbe_exact', NULL, NULL)
(-833, '42', '000', 0, 626, 'sysf_argmustbe_exact_or_fp', NULL, NULL)
(-833, '42', '000', 0, 627, 'sysf_argviolates_uuidtype', NULL, NULL)
(-833, '42', '000', 0, 628, 'sysf_argviolates_uuidlen', NULL, NULL)
(-833, '42', '000', 0, 629, 'sysf_argviolates_uuidfmt', NULL, NULL)
(-833, '42', '000', 0, 630, 'sysf_argviolates_guidigits', NULL, NULL)
(-833, '42', '000', 0, 631, 'sysf_invalid_addpart_time', NULL, NULL)
(-833, '42', '000', 0, 632, 'sysf_invalid_add_datetime', NULL, NULL)
(-833, '42', '000', 0, 633, 'sysf_invalid_addpart_dtime', NULL, NULL)
(-833, '42', '000', 0, 634, 'sysf_invalid_add_dtime_rc', NULL, NULL)
(-833, '42', '000', 0, 635, 'sysf_invalid_diff_dtime', NULL, NULL)
(-833, '42', '000', 0, 636, 'sysf_invalid_timediff', NULL, NULL)
(-833, '42', '000', 0, 637, 'sysf_invalid_tstamptimediff', NULL, NULL)
(-833, '42', '000', 0, 638, 'sysf_invalid_datetimediff', NULL, NULL)
(-833, '42', '000', 0, 639, 'sysf_invalid_diffpart', NULL, NULL)
(-833, '42', '000', 0, 640, 'sysf_argmustbe_positive', NULL, NULL)
(-833, '42', '000', 0, 641, 'sysf_basemustbe_positive', NULL, NULL)
(-833, '42', '000', 0, 642, 'sysf_argnmustbe_nonneg', NULL, NULL)
(-833, '42', '000', 0, 643, 'sysf_argnmustbe_positive', NULL, NULL)
(-833, '42', '000', 0, 644, 'sysf_invalid_zeropowneg', NULL, NULL)
(-833, '42', '000', 0, 645, 'sysf_invalid_negpowfp', NULL, NULL)
(-833, '42', '000', 0, 646, 'sysf_invalid_scale', NULL, NULL)
(-833, '42', '000', 0, 647, 'sysf_argmustbe_nonneg', NULL, NULL)
(-833, '42', '000', 0, 648, 'sysf_binuuid_mustbe_str', NULL, NULL)
(-833, '42', '000', 0, 649, 'sysf_binuuid_wrongsize', NULL, NULL)
-- End of expression_eval_err subcodes
(-902, 'HY', '000', 0, 650, 'missing_required_spb', NULL, NULL)
(-902, '08', '006', 0, 651, 'net_server_shutdown', NULL, NULL)
(-924, '08', '001', 0, 652, 'bad_conn_str', NULL, NULL)
(-901, 'HY', '000', 0, 653, 'bad_epb_form', NULL, NULL)
(-902, '08', '004', 0, 654, 'no_threads', NULL, NULL)
(-902, '08', '006', 0, 655, 'net_event_connect_timeout', NULL, NULL)
-- More extras for isc_expression_eval_err
(-833, '42', '000', 0, 656, 'sysf_argmustbe_nonzero', NULL, NULL)
(-833, '42', '000', 0, 657, 'sysf_argmustbe_range_inc1_1', NULL, NULL)
(-833, '42', '000', 0, 658, 'sysf_argmustbe_gteq_one', NULL, NULL)
(-833, '42', '000', 0, 659, 'sysf_argmustbe_range_exc1_1', NULL, NULL)
-- End of extras for isc_expression_eval_err
-- Not sure about the SQL code and class here
(-104, 'HY', '000', 0, 660, 'internal_rejected_params', NULL, NULL)
(-833, '42', '000', 0, 661, 'sysf_fp_overflow', NULL, NULL)
(-901, '39', '000', 0, 662, 'udf_fp_overflow', NULL, NULL)
(-901, '39', '000', 0, 663, 'udf_fp_nan', NULL, NULL)
(-902, '42', '000', 0, 664, 'instance_conflict', NULL, NULL)
(-901, 'HY', '000', 0, 665, 'out_of_temp_space', NULL, NULL)
(-901, '42', '000', 0, 666, 'eds_expl_tran_ctrl', NULL, NULL)
(-902, '28', '000', 0, 667, 'no_trusted_spb', NULL, NULL)
(-901, '42', '000', 0, 668, 'package_name', NULL, NULL)
(-901, '22', '006', 0, 669, 'cannot_make_not_null', NULL, NULL)
(-901, '0A', '000', 0, 670, 'feature_removed', NULL, NULL)
(-901, '00', '000', 0, 671, 'view_name', NULL, NULL)
(-904, '08', '006', 0, 672, 'lock_dir_access', NULL, NULL)
(-901, 'HY', '106', 0, 673, 'invalid_fetch_option', NULL, NULL)
(-901, '2F', '000', 0, 674, 'bad_fun_BLR', NULL, NULL)
(-901, '2F', '000', 0, 675, 'func_pack_not_implemented', NULL, NULL)
(-901, '2F', '000', 0, 676, 'proc_pack_not_implemented', NULL, NULL)
(-901, '39', '000', 0, 677, 'eem_func_not_returned', NULL, NULL)
(-901, '39', '000', 0, 678, 'eem_proc_not_returned', NULL, NULL)
(-901, '39', '000', 0, 679, 'eem_trig_not_returned', NULL, NULL)
(-901, '39', '000', 0, 680, 'eem_bad_plugin_ver', NULL, NULL)
(-901, '39', '000', 0, 681, 'eem_engine_notfound', NULL, NULL)
(-532, '08', '002', 0, 682, 'attachment_in_use', NULL, NULL)
(-532, '25', 'S02', 0, 683, 'transaction_in_use', NULL, NULL)
(-901, '39', '000', 0, 684, 'pman_cannot_load_plugin', NULL, NULL)
(-901, '00', '000', 0, 685, 'pman_module_notfound', NULL, NULL)
(-901, '00', '000', 0, 686, 'pman_entrypoint_notfound', NULL, NULL)
(-901, '00', '000', 0, 687, 'pman_module_bad', NULL, NULL)
(-901, '00', '000', 0, 688, 'pman_plugin_notfound', NULL, NULL)
(-833, '42', '000', 0, 689, 'sysf_invalid_trig_namespace', NULL, NULL)
(-901, '22', '002', 0, 690, 'unexpected_null', NULL, NULL)
(-901, '22', '00G', 0, 691, 'type_notcompat_blob', NULL, NULL)
(-901, '22', '003', 0, 692, 'invalid_date_val', NULL, NULL)
(-901, '22', '003', 0, 693, 'invalid_time_val', NULL, NULL)
(-901, '22', '003', 0, 694, 'invalid_timestamp_val', NULL, NULL)
(-901, '22', '003', 0, 695, 'invalid_index_val', NULL, NULL)
(-836, '00', '000', 0, 696, 'formatted_exception', NULL, 'ERROR')
(-532, 'HY', '018', 0, 697, 'async_active', NULL, NULL)
(-901, '42', '000', 0, 698, 'private_function', NULL, NULL)
(-901, '42', '000', 0, 699, 'private_procedure', NULL, NULL)
(-904, '24', '000', 0, 700, 'request_outdated', NULL, NULL)
(-901, '08', '003', 0, 701, 'bad_events_handle', NULL, 'ERROR')
(-104, 'XX', '000', 0, 702, 'cannot_copy_stmt', NULL, NULL)
(-104, '22', '000', 0, 703, 'invalid_boolean_usage', NULL, NULL)
(-833, '42', '000', 0, 704, 'sysf_argscant_both_be_zero', NULL, NULL)
(-901, 'HY', '000', 0, 705, 'spb_no_id', NULL, NULL)
(-901, '42', '000', 0, 706, 'ee_blr_mismatch_null', NULL, NULL)
(-901, '42', '000', 0, 707, 'ee_blr_mismatch_length', NULL, NULL)
(-406, '42', '000', 0, 708, 'ss_out_of_bounds', NULL, NULL)
(-902, '28', '000', 0, 709, 'missing_data_structures', NULL, NULL)
(-902, '42', '000', 0, 710, 'protect_sys_tab', NULL, NULL)
-- If you have better SQL code for this, change it.
(-901, '2F', '000', 0, 711, 'libtommath_generic', NULL, NULL)
(-902, 'HY', '000', 0, 712, 'wroblrver2', NULL, NULL)
(-551, '28', '000', 0, 713, 'trunc_limits', NULL, NULL)
(-551, '28', '000', 0, 714, 'info_access', NULL, NULL)
(-104, 'HY', '024', 0, 715, 'svc_no_stdin', NULL, NULL)
(-551, '28', '000', 0, 716, 'svc_start_failed', NULL, NULL)
(-104, 'HY', '024', 0, 717, 'svc_no_switches', NULL, NULL)
(-104, 'HY', '109', 0, 718, 'svc_bad_size', NULL, NULL)
(-104, 'HY', '024', 0, 719, 'no_crypt_plugin', NULL, NULL)
(-104, '22', '001', 0, 720, 'cp_name_too_long', NULL, NULL)
(-901, '42', '818', 0, 721, 'cp_process_active', NULL, NULL)
(-901, '42', '818', 0, 722, 'cp_already_crypted', NULL, NULL)
(-902, 'XX', '000', 0, 723, 'decrypt_error', NULL, NULL)
(-902, '39', '000', 0, 724, 'no_providers', NULL, NULL)
(-104, '42', '818', 0, 725, 'null_spb', NULL, NULL)
(-833, '42', '000', 0, 726, 'max_args_exceeded', NULL, NULL)
(-901, '42', '000', 0, 727, 'ee_blr_mismatch_names_count', NULL, NULL)
(-901, '42', '000', 0, 728, 'ee_blr_mismatch_name_not_found', NULL, NULL)
(-901, '26', '000', 0, 729, 'bad_result_set', NULL, NULL)
(-804, '07', '000', 0, 730, 'wrong_message_length', NULL, NULL)
(-804, '07', '000', 0, 731, 'no_output_format', NULL, NULL)
(-804, 'HY', '021', 0, 732, 'item_finish', NULL, NULL)
(-902, 'XX', '000', 0, 733, 'miss_config', NULL, NULL)
(-902, 'XX', '000', 0, 734, 'conf_line', NULL, NULL)
(-902, 'XX', '000', 0, 735, 'conf_include', NULL, NULL)
(-902, 'XX', '000', 0, 736, 'include_depth', NULL, NULL)
(-902, 'XX', '000', 0, 737, 'include_miss', NULL, NULL)
(-552, '28', '000', 0, 738, 'protect_ownership', NULL, NULL)
(-901, 'HY', '000', 0, 739, 'badvarnum', NULL, NULL)
(-902, '28', '000', 0, 740, 'sec_context', NULL, NULL);
(-902, '28', '000', 0, 741, 'multi_segment', NULL, NULL);
(-902, '28', '000', 0, 742, 'login_changed', NULL, NULL);
(-902, '28', '000', 0, 743, 'auth_handshake_limit', NULL, NULL);
(-902, '28', '000', 0, 744, 'wirecrypt_incompatible', NULL, NULL);
(-902, '28', '000', 0, 745, 'miss_wirecrypt', NULL, NULL);
(-902, '28', '000', 0, 746, 'wirecrypt_key', NULL, NULL);
(-902, '28', '000', 0, 747, 'wirecrypt_plugin', NULL, NULL);
(-902, '28', '000', 0, 748, 'secdb_name', NULL, NULL);
(-902, '28', '000', 0, 749, 'auth_data', NULL, NULL);
(-902, '28', '000', 0, 750, 'auth_datalength', NULL, NULL);
(-901, 'HY', '007', 0, 751, 'info_unprepared_stmt', NULL, NULL);
(-901, 'HY', '007', 0, 752, 'idx_key_value', NULL, NULL);
(-901, 'HY', '000', 0, 753, 'forupdate_virtualtbl', NULL, NULL);
(-901, 'HY', '000', 0, 754, 'forupdate_systbl', NULL, NULL);
(-901, 'HY', '000', 0, 755, 'forupdate_temptbl', NULL, NULL);
(-901, '42', '000', 0, 756, 'cant_modify_sysobj', NULL, NULL);
(-901, '08', '004', 0, 757, 'server_misconfigured', NULL, NULL);
(-901, '0A', '000', 0, 758, 'alter_role', NULL, NULL);
(-901, '42', 'S01', 0, 759, 'map_already_exists', NULL, NULL);
(-901, '42', 'S02', 0, 760, 'map_not_exists', NULL, NULL);
(-901, '08', '004', 0, 761, 'map_load', NULL, NULL);
(-901, '08', '004', 0, 762, 'map_aster', NULL, NULL);
(-901, '08', '004', 0, 763, 'map_multi', NULL, NULL);
(-901, '08', '004', 0, 764, 'map_undefined', NULL, NULL);
(-924, 'HY', '000', 0, 765, 'baddpb_damaged_mode', NULL, NULL);
(-924, 'HY', '000', 0, 766, 'baddpb_buffers_range', NULL, NULL);
(-924, 'HY', '000', 0, 767, 'baddpb_temp_buffers', NULL, NULL);
(-901, '0A', '000', 0, 768, 'map_nodb', NULL, NULL);
(-901, '0A', '000', 0, 769, 'map_notable', NULL, NULL);
(-901, '0P', '000', 0, 770, 'miss_trusted_role', NULL, NULL);
(-901, '0P', '000', 0, 771, 'set_invalid_role', NULL, NULL);
(-596, 'HY', '109', 0, 772, 'cursor_not_positioned', NULL, NULL)
(-901, '42', '702', 0, 773, 'dup_attribute', NULL, NULL);
(-901, '42', '000', 0, 774, 'dyn_no_priv', NULL, NULL)
(-901, '42', '000', 0, 775, 'dsql_cant_grant_option', NULL, NULL);
(-904, '40', '001', 0, 776, 'read_conflict', NULL, NULL);
(-901, '08', '004', 0, 777, 'crdb_load', NULL, NULL);
(-901, '0A', '000', 0, 778, 'crdb_nodb', NULL, NULL);
(-901, '0A', '000', 0, 779, 'crdb_notable', NULL, NULL);
(-804, 'HY', '000', 0, 780, 'interface_version_too_old', NULL, NULL)
(-170, '07', '001', 0, 781, 'fun_param_mismatch', NULL, NULL)
(-901, 'HY', '000', 0, 782, 'savepoint_backout_err', NULL, NULL)
(-291, '42', '000', 0, 783, 'domain_primary_key_notnull', NULL, NULL)
(-204, '2C', '000', 0, 784, 'invalid_attachment_charset', NULL, NULL)
(-901, '08', '004', 0, 785, 'map_down', NULL, NULL)
(-902, '08', '006', 0, 786, 'login_error', NULL, NULL)
(-902, '08', '006', 0, 787, 'already_opened', NULL, NULL)
(-902, '08', '006', 0, 788, 'bad_crypt_key', NULL, NULL)
(-901, 'XX', '000', 0, 789, 'encrypt_error', NULL, NULL)
-- GFIX
(-901, '00', '000', 3, 1, 'gfix_db_name', NULL, NULL)
(-901, '00', '000', 3, 2, 'gfix_invalid_sw', NULL, NULL)
(-901, '00', '000', 3, 4, 'gfix_incmp_sw', NULL, NULL)
(-901, '00', '000', 3, 5, 'gfix_replay_req', NULL, NULL)
(-901, '00', '000', 3, 6, 'gfix_pgbuf_req', NULL, NULL)
(-901, '00', '000', 3, 7, 'gfix_val_req', NULL, NULL)
(-901, '00', '000', 3, 8, 'gfix_pval_req', NULL, NULL)
(-901, '00', '000', 3, 9, 'gfix_trn_req', NULL, NULL)
(-901, '00', '000', 3, 12, 'gfix_full_req', NULL, NULL)
(-901, '00', '000', 3, 13, 'gfix_usrname_req', NULL, NULL)
(-901, '00', '000', 3, 14, 'gfix_pass_req', NULL, NULL)
(-901, '00', '000', 3, 15, 'gfix_subs_name', NULL, NULL)
(-901, '00', '000', 3, 16, 'gfix_wal_req', NULL, NULL)
(-901, '00', '000', 3, 17, 'gfix_sec_req', NULL, NULL)
(-901, '00', '000', 3, 18, 'gfix_nval_req', NULL, NULL)
(-901, '00', '000', 3, 19, 'gfix_type_shut', NULL, NULL)
(-901, '00', '000', 3, 20, 'gfix_retry', NULL, NULL)
(-901, '00', '000', 3, 23, 'gfix_retry_db', NULL, NULL)
(-901, '00', '000', 3, 63, 'gfix_exceed_max', NULL, NULL)
(-901, '00', '000', 3, 64, 'gfix_corrupt_pool', NULL, NULL)
(-901, '00', '000', 3, 65, 'gfix_mem_exhausted', NULL, NULL)
(-901, '00', '000', 3, 66, 'gfix_bad_pool', NULL, NULL)
(-901, '00', '000', 3, 67, 'gfix_trn_not_valid', NULL, NULL)
(-901, '00', '000', 3, 84, 'gfix_unexp_eoi', NULL, NULL)
(-901, '00', '000', 3, 90, 'gfix_recon_fail', NULL, NULL)
(-901, '00', '000', 3, 108, 'gfix_trn_unknown', NULL, NULL)
(-901, '00', '000', 3, 110, 'gfix_mode_req', NULL, NULL)
(-901, '00', '000', 3, 114, 'gfix_pzval_req', NULL, NULL)
-- DSQL
(-607, 'HY', '000', 7, 2, 'dsql_dbkey_from_non_table', NULL, NULL)
(-104, 'HY', '000', 7, 3, 'dsql_transitional_numeric', NULL, NULL)
(301, '01', '000', 7, 4, 'dsql_dialect_warning_expr', NULL, NULL)
(-104, 'HY', '000', 7, 5, 'sql_db_dialect_dtype_unsupport', NULL, NULL)
(-817, 'HY', '000', 7, 7, 'sql_dialect_conflict_num', NULL, NULL)
(301, 'HY', '104', 7, 8, 'dsql_warning_number_ambiguous', NULL, NULL)
(301, 'HY', '104', 7, 9, 'dsql_warning_number_ambiguous1', NULL, NULL)
(301, 'HY', '104', 7, 10, 'dsql_warn_precision_ambiguous', NULL, NULL)
(301, 'HY', '104', 7, 11, 'dsql_warn_precision_ambiguous1', NULL, NULL)
(301, 'HY', '104', 7, 12, 'dsql_warn_precision_ambiguous2', NULL, NULL)
(-204, '42', '702', 7, 13, 'dsql_ambiguous_field_name', NULL, NULL)
(-607, '38', '000', 7, 14, 'dsql_udf_return_pos_err', NULL, NULL)
(-104, 'HY', '000', 7, 15, 'dsql_invalid_label', NULL, NULL)
(-104, 'HY', '004', 7, 16, 'dsql_datatypes_not_comparable', NULL, NULL)
(-504, '24', '000', 7, 17, 'dsql_cursor_invalid', NULL, NULL)
(-502, '24', '000', 7, 18, 'dsql_cursor_redefined', NULL, NULL)
(-502, '34', '000', 7, 19, 'dsql_cursor_not_found', NULL, NULL)
(-502, '24', '000', 7, 20, 'dsql_cursor_exists', NULL, NULL)
(-502, '34', '000', 7, 21, 'dsql_cursor_rel_ambiguous', NULL, NULL)
(-502, '34', '000', 7, 22, 'dsql_cursor_rel_not_found', NULL, NULL)
(-502, '24', '000', 7, 23, 'dsql_cursor_not_open', NULL, NULL)
(-607, 'HY', '004', 7, 24, 'dsql_type_not_supp_ext_tab', NULL, NULL)
(-804, '0A', '000', 7, 25, 'dsql_feature_not_supported_ods', NULL, NULL)
(-660, '22', '000', 7, 26, 'primary_key_required', NULL, NULL)
(-313, '42', '000', 7, 27, 'upd_ins_doesnt_match_pk', NULL, NULL)
(-313, '42', '000', 7, 28, 'upd_ins_doesnt_match_matching', NULL, NULL)
(-817, '54', '001', 7, 29, 'upd_ins_with_complex_view', NULL, NULL)
(-817, '42', '000', 7, 30, 'dsql_incompatible_trigger_type', NULL, NULL)
(-817, '42', '000', 7, 31, 'dsql_db_trigger_type_cant_change', NULL, NULL)
(-607, 'HY', '000', 7, 32, 'dsql_record_version_table', NULL, NULL)
(-802, '07', '002', 7, 33, 'dsql_invalid_sqlda_version', NULL, NULL)
(-802, '07', '002', 7, 34, 'dsql_sqlvar_index', NULL, NULL)
(-802, '07', '002', 7, 35, 'dsql_no_sqlind', NULL, NULL)
(-802, '07', '002', 7, 36, 'dsql_no_sqldata', NULL, NULL)
(-802, '07', '002', 7, 37, 'dsql_no_input_sqlda', NULL, NULL)
(-802, '07', '002', 7, 38, 'dsql_no_output_sqlda', NULL, NULL)
(-313, '07', '001', 7, 39, 'dsql_wrong_param_num', NULL, NULL)
--  DYN
(-901, '42', '000', 8, 37, 'dyn_filter_not_found', NULL, NULL)
(-901, '42', '000', 8, 41, 'dyn_func_not_found', NULL, NULL)
(-901, '42', '000', 8, 48, 'dyn_index_not_found', NULL, NULL)
(-901, '42', '000', 8, 54, 'dyn_view_not_found', NULL, NULL)
(-901, '42', '000', 8, 89, 'dyn_domain_not_found', NULL, NULL)
(-901, '42', '000', 8, 109, 'dyn_cant_modify_auto_trig', NULL, NULL)
(-901, '42', 'S01', 8, 132, 'dyn_dup_table', NULL, NULL)
(-901, '42', '000', 8, 140, 'dyn_proc_not_found', NULL, NULL)
(-901, '42', '000', 8, 144, 'dyn_exception_not_found', NULL, NULL)
(-901, '42', '000', 8, 146, 'dyn_proc_param_not_found', NULL, NULL)
(-901, '42', '000', 8, 147, 'dyn_trig_not_found', NULL, NULL)
(-901, '42', '000', 8, 151, 'dyn_charset_not_found', NULL, NULL)
(-901, '42', '000', 8, 152, 'dyn_collation_not_found', NULL, NULL)
(-901, '42', '000', 8, 155, 'dyn_role_not_found', NULL, NULL)
(-901, '42', '000', 8, 159, 'dyn_name_longer', NULL, NULL)
(-901, '42', 'S22', 8, 176, 'dyn_column_does_not_exist', NULL, NULL)
(-901, '28', '000', 8, 188, 'dyn_role_does_not_exist', NULL, NULL)
(-901, '28', '000', 8, 189, 'dyn_no_grant_admin_opt', NULL, NULL)
(-901, '28', '000', 8, 190, 'dyn_user_not_role_member', NULL, NULL)
(-901, '28', '000', 8, 191, 'dyn_delete_role_failed', NULL, NULL)
(-901, '28', '000', 8, 192, 'dyn_grant_role_to_user', NULL, NULL)
(-901, '28', '000', 8, 193, 'dyn_inv_sql_role_name', NULL, NULL)
(-901, '42', '000', 8, 194, 'dyn_dup_sql_role', NULL, NULL)
(-901, '28', '000', 8, 195, 'dyn_kywd_spec_for_role', NULL, NULL)
(-901, '28', '000', 8, 196, 'dyn_roles_not_supported', NULL, NULL)
(-612, '42', '000', 8, 204, 'dyn_domain_name_exists', NULL, NULL)
(-612, '42', 'S21', 8, 205, 'dyn_field_name_exists', NULL, NULL)
(-383, '42', '000', 8, 206, 'dyn_dependency_exists', NULL, NULL)
(-315, '42', '000', 8, 207, 'dyn_dtype_invalid', NULL, NULL)
(-829, '42', '000', 8, 208, 'dyn_char_fld_too_small', NULL, NULL)
(-829, '42', '000', 8, 209, 'dyn_invalid_dtype_conversion', NULL, NULL)
(-829, '42', '000', 8, 210, 'dyn_dtype_conv_invalid', NULL, NULL)
(-901, '42', '000', 8, 212, 'dyn_zero_len_id', NULL, NULL)
(-901, '42', '000', 8, 214, 'dyn_gen_not_found', NULL, NULL)
(-829, '2C', '000', 8, 221, 'max_coll_per_charset', NULL, NULL)
(-829, 'HY', '000', 8, 222, 'invalid_coll_attr', NULL, NULL)
(-901, 'HY', '000', 8, 232, 'dyn_wrong_gtt_scope', NULL, NULL)
(-901, 'HY', '000', 8, 235, 'dyn_coll_used_table', NULL, NULL)
(-901, 'HY', '000', 8, 236, 'dyn_coll_used_domain', NULL, NULL)
(-607, 'HY', '000', 8, 237, 'dyn_cannot_del_syscoll', NULL, NULL)
(-901, 'HY', '000', 8, 238, 'dyn_cannot_del_def_coll', NULL, NULL)
(-901, '42', '000', 8, 241, 'dyn_table_not_found', NULL, NULL)
(-901, 'HY', '000', 8, 243, 'dyn_coll_used_procedure', NULL, NULL)
(-829, '42', '000', 8, 244, 'dyn_scale_too_big', NULL, NULL)
(-829, '42', '000', 8, 245, 'dyn_precision_too_small', NULL, NULL)
(106,  '42', '000', 8, 247, 'dyn_miss_priv_warning', NULL, NULL)
(-901, '0A', '000', 8, 248, 'dyn_ods_not_supp_feature', NULL, NULL)
(-829, '42', '000', 8, 249, 'dyn_cannot_addrem_computed', NULL, NULL)
(-901, '42', '000', 8, 250, 'dyn_no_empty_pw', NULL, NULL)
(-901, '42', 'S11', 8, 251, 'dyn_dup_index', NULL, NULL)
(-901, '42', '000', 8, 256, 'dyn_package_not_found', NULL, NULL)
(-901, '42', '000', 8, 257, 'dyn_schema_not_found', NULL, NULL)
(-607, 'HY', '000', 8, 258, 'dyn_cannot_mod_sysproc', NULL, NULL)
(-607, 'HY', '000', 8, 259, 'dyn_cannot_mod_systrig', NULL, NULL)
(-607, 'HY', '000', 8, 260, 'dyn_cannot_mod_sysfunc', NULL, NULL)
(-607, 'HY', '000', 8, 261, 'dyn_invalid_ddl_proc', NULL, NULL)
(-607, 'HY', '000', 8, 262, 'dyn_invalid_ddl_trig' NULL, NULL)
(-901, '42', '000', 8, 263, 'dyn_funcnotdef_package', NULL, NULL)
(-901, '42', '000', 8, 264, 'dyn_procnotdef_package', NULL, NULL)
(-901, '42', '000', 8, 265, 'dyn_funcsignat_package', NULL, NULL)
(-901, '42', '000', 8, 266, 'dyn_procsignat_package', NULL, NULL)
(-901, '42', '000', 8, 267, 'dyn_defvaldecl_package_proc', NULL, NULL)
(-901, '42', '000', 8, 269, 'dyn_package_body_exists', NULL, NULL)
(-607, 'HY', '000', 8, 270, 'dyn_invalid_ddl_func' NULL, NULL)
(-901, '42', '000', 8, 271, 'dyn_newfc_oldsyntax', NULL, NULL)
(-901, '42', '000', 8, 278, 'dyn_func_param_not_found', NULL, NULL)
(-901, '42', '000', 8, 279, 'dyn_routine_param_not_found', NULL, NULL)
(-901, '42', '000', 8, 280, 'dyn_routine_param_ambiguous', NULL, NULL)
(-901, 'HY', '000', 8, 281, 'dyn_coll_used_function', NULL, NULL)
(-901, 'HY', '000', 8, 282, 'dyn_domain_used_function', NULL, NULL)
(-901, '42', '000', 8, 283, 'dyn_alter_user_no_clause', NULL, NULL)
(-901, '42', '000', 8, 286, 'dyn_duplicate_package_item', NULL, NULL)
(-901, '42', '000', 8, 287, 'dyn_cant_modify_sysobj', NULL, NULL)
(-901, '42', '000', 8, 288, 'dyn_cant_use_zero_increment', NULL, NULL)
(-901, '42', '000', 8, 289, 'dyn_cant_use_in_foreignkey', NULL, NULL)
(-901, '42', '000', 8, 290, 'dyn_defvaldecl_package_func', NULL, NULL)
--  GBAK
(-901, '00', '000', 12, 1, 'gbak_unknown_switch', NULL, NULL)
(-901, '00', '000', 12, 2, 'gbak_page_size_missing', NULL, NULL)
(-901, '00', '000', 12, 3, 'gbak_page_size_toobig', NULL, NULL)
(-901, '00', '000', 12, 4, 'gbak_redir_ouput_missing', NULL, NULL)
(-901, '00', '000', 12, 5, 'gbak_switches_conflict', NULL, NULL)
(-901, '00', '000', 12, 6, 'gbak_unknown_device', NULL, NULL)
(-901, '00', '000', 12, 7, 'gbak_no_protection', NULL, NULL)
(-901, '00', '000', 12, 8, 'gbak_page_size_not_allowed', NULL, NULL)
(-901, '00', '000', 12, 9, 'gbak_multi_source_dest', NULL, NULL)
(-901, '00', '000', 12, 10, 'gbak_filename_missing', NULL, NULL)
(-901, '00', '000', 12, 11, 'gbak_dup_inout_names', NULL, NULL)
(-901, '00', '000', 12, 12, 'gbak_inv_page_size', NULL, NULL)
(-901, '00', '000', 12, 13, 'gbak_db_specified', NULL, NULL)
(-901, '00', '000', 12, 14, 'gbak_db_exists', NULL, NULL)
(-901, '00', '000', 12, 15, 'gbak_unk_device', NULL, NULL)
(-901, '00', '000', 12, 20, 'gbak_blob_info_failed', NULL, NULL)
(-901, '00', '000', 12, 21, 'gbak_unk_blob_item', NULL, NULL)
(-901, '00', '000', 12, 22, 'gbak_get_seg_failed', NULL, NULL)
(-901, '00', '000', 12, 23, 'gbak_close_blob_failed', NULL, NULL)
(-901, '00', '000', 12, 24, 'gbak_open_blob_failed', NULL, NULL)
COMMIT WORK;
(-901, '00', '000', 12, 25, 'gbak_put_blr_gen_id_failed', NULL, NULL)
(-901, '00', '000', 12, 26, 'gbak_unk_type', NULL, NULL)
(-901, '00', '000', 12, 27, 'gbak_comp_req_failed', NULL, NULL)
(-901, '00', '000', 12, 28, 'gbak_start_req_failed', NULL, NULL)
(-901, '00', '000', 12, 29, 'gbak_rec_failed', NULL, NULL)
(-901, '00', '000', 12, 30, 'gbak_rel_req_failed', NULL, NULL)
(-901, '00', '000', 12, 31, 'gbak_db_info_failed', NULL, NULL)
(-901, '00', '000', 12, 32, 'gbak_no_db_desc', NULL, NULL)
(-901, '00', '000', 12, 33, 'gbak_db_create_failed', NULL, NULL)
(-901, '00', '000', 12, 34, 'gbak_decomp_len_error', NULL, NULL)
(-901, '00', '000', 12, 35, 'gbak_tbl_missing', NULL, NULL)
(-901, '00', '000', 12, 36, 'gbak_blob_col_missing', NULL, NULL)
(-901, '00', '000', 12, 37, 'gbak_create_blob_failed', NULL, NULL)
(-901, '00', '000', 12, 38, 'gbak_put_seg_failed', NULL, NULL)
(-901, '00', '000', 12, 39, 'gbak_rec_len_exp', NULL, NULL)
(-901, '00', '000', 12, 40, 'gbak_inv_rec_len', NULL, NULL)
(-901, '00', '000', 12, 41, 'gbak_exp_data_type', NULL, NULL)
(-901, '00', '000', 12, 42, 'gbak_gen_id_failed', NULL, NULL)
(-901, '00', '000', 12, 43, 'gbak_unk_rec_type', NULL, NULL)
(-901, '00', '000', 12, 44, 'gbak_inv_bkup_ver', NULL, NULL)
(-901, '00', '000', 12, 45, 'gbak_missing_bkup_desc', NULL, NULL)
(-901, '00', '000', 12, 46, 'gbak_string_trunc', NULL, NULL)
(-901, '00', '000', 12, 47, 'gbak_cant_rest_record', NULL, NULL)
(-901, '00', '000', 12, 48, 'gbak_send_failed', NULL, NULL)
(-901, '00', '000', 12, 49, 'gbak_no_tbl_name', NULL, NULL)
(-901, '00', '000', 12, 50, 'gbak_unexp_eof', NULL, NULL)
(-901, '00', '000', 12, 51, 'gbak_db_format_too_old', NULL, NULL)
(-901, '00', '000', 12, 52, 'gbak_inv_array_dim', NULL, NULL)
(-901, '00', '000', 12, 55, 'gbak_xdr_len_expected', NULL, NULL)
(-901, '00', '000', 12, 65, 'gbak_open_bkup_error', NULL, NULL)
(-901, '00', '000', 12, 66, 'gbak_open_error', NULL, NULL)
(-901, '00', '000', 12, 182, 'gbak_missing_block_fac', NULL, NULL)
(-901, '00', '000', 12, 183, 'gbak_inv_block_fac', NULL, NULL)
(-901, '00', '000', 12, 184, 'gbak_block_fac_specified', NULL, NULL)
(-901, '00', '000', 12, 188, 'gbak_missing_username', NULL, NULL)
(-901, '00', '000', 12, 189, 'gbak_missing_password', NULL, NULL)
(-901, '00', '000', 12, 200, 'gbak_missing_skipped_bytes', NULL, NULL)
(-901, '00', '000', 12, 201, 'gbak_inv_skipped_bytes', NULL, NULL)
(-901, '00', '000', 12, 213, 'gbak_err_restore_charset', NULL, NULL)
(-901, '00', '000', 12, 215, 'gbak_err_restore_collation', NULL, NULL)
(-901, '00', '000', 12, 220, 'gbak_read_error', NULL, NULL)
(-901, '00', '000', 12, 221, 'gbak_write_error', NULL, NULL)
(-901, '00', '000', 12, 233, 'gbak_db_in_use', NULL, NULL)
(-901, '00', '000', 12, 238, 'gbak_sysmemex', NULL, NULL)
(-901, '00', '000', 12, 250, 'gbak_restore_role_failed', NULL, NULL)
(-901, '00', '000', 12, 253, 'gbak_role_op_missing', NULL, NULL)
(-901, '00', '000', 12, 258, 'gbak_page_buffers_missing', NULL, NULL)
(-901, '00', '000', 12, 259, 'gbak_page_buffers_wrong_param', NULL, NULL)
(-901, '00', '000', 12, 260, 'gbak_page_buffers_restore', NULL, NULL)
(-901, '00', '000', 12, 262, 'gbak_inv_size', NULL, NULL)
(-901, '00', '000', 12, 263, 'gbak_file_outof_sequence', NULL, NULL)
(-901, '00', '000', 12, 264, 'gbak_join_file_missing', NULL, NULL)
(-901, '00', '000', 12, 265, 'gbak_stdin_not_supptd', NULL, NULL)
(-901, '00', '000', 12, 266, 'gbak_stdout_not_supptd', NULL, NULL)
(-901, '00', '000', 12, 267, 'gbak_bkup_corrupt', NULL, NULL)
(-901, '00', '000', 12, 268, 'gbak_unk_db_file_spec', NULL, NULL)
(-901, '00', '000', 12, 269, 'gbak_hdr_write_failed', NULL, NULL)
(-901, '00', '000', 12, 270, 'gbak_disk_space_ex', NULL, NULL)
(-901, '00', '000', 12, 271, 'gbak_size_lt_min', NULL, NULL)
(-901, '00', '000', 12, 273, 'gbak_svc_name_missing', NULL, NULL)
(-901, '00', '000', 12, 274, 'gbak_not_ownr', NULL, NULL)
(-901, '00', '000', 12, 279, 'gbak_mode_req', NULL, NULL)
(-901, '00', '000', 12, 281, 'gbak_just_data', NULL, NULL)
(-901, '00', '000', 12, 282, 'gbak_data_only', NULL, NULL)
(-901, '00', '000', 12, 326, 'gbak_missing_interval', NULL, NULL)
(-901, '00', '000', 12, 327, 'gbak_wrong_interval', NULL, NULL)
(-901, '00', '000', 12, 329, 'gbak_verify_verbint', NULL, NULL)
(-901, '00', '000', 12, 330, 'gbak_option_only_restore', NULL, NULL)
(-901, '00', '000', 12, 331, 'gbak_option_only_backup', NULL, NULL)
(-901, '00', '000', 12, 332, 'gbak_option_conflict', NULL, NULL)
(-901, '00', '000', 12, 333, 'gbak_param_conflict', NULL, NULL)
(-901, '00', '000', 12, 334, 'gbak_option_repeated', NULL, NULL)
(-901, '00', '000', 12, 339, 'gbak_max_dbkey_recursion', NULL, NULL)
(-901, '00', '000', 12, 340, 'gbak_max_dbkey_length', NULL, NULL)
(-901, '00', '000', 12, 341, 'gbak_invalid_metadata', NULL, NULL)
(-901, '00', '000', 12, 342, 'gbak_invalid_data', NULL, NULL)
(-901, '00', '000', 12, 344, 'gbak_inv_bkup_ver2', NULL, NULL)
(-901, '00', '000', 12, 348, 'gbak_db_format_too_old2', NULL, NULL)
--  SQLERR
(-804, 'HY', '000', 13, 917, 'dsql_too_old_ods', NULL, NULL)
(-607, '42', 'S02', 13, 918, 'dsql_table_not_found', NULL, NULL)
(-607, '42', 'S02', 13, 919, 'dsql_view_not_found', NULL, NULL)
(-206, '42', '000', 13, 920, 'dsql_line_col_error', NULL, NULL)
(-206, '42', '000', 13, 921, 'dsql_unknown_pos', NULL, NULL)
(-206, 'HY', '000', 13, 922, 'dsql_no_dup_name', NULL, NULL)
(-901, '07', '002', 13, 923, 'dsql_too_many_values', NULL, NULL)
(-607, 'HY', '000', 13, 924, 'dsql_no_array_computed', NULL, NULL)
(-637, '00', '000', 13, 925, 'dsql_implicit_domain_name', NULL, NULL)
(-607, '42', '000', 13, 926, 'dsql_only_can_subscript_array', NULL, NULL)
(-104, '54', '011', 13, 927, 'dsql_max_sort_items', NULL, NULL)
(-104, '54', '011', 13, 928, 'dsql_max_group_items', NULL, NULL)
(-104, '42', '000', 13, 929, 'dsql_conflicting_sort_field', NULL, NULL)
(-104, '54', '001', 13, 930, 'dsql_derived_table_more_columns', NULL, NULL)
(-104, '54', '001', 13, 931, 'dsql_derived_table_less_columns', NULL, NULL)
(-104, '42', '000', 13, 932, 'dsql_derived_field_unnamed', NULL, NULL)
(-104, '42', '000', 13, 933, 'dsql_derived_field_dup_name', NULL, NULL)
(-104, '42', '000', 13, 934, 'dsql_derived_alias_select', NULL, NULL)
(-104, '42', '000', 13, 935, 'dsql_derived_alias_field', NULL, NULL)
(-104, '42', '000', 13, 936, 'dsql_auto_field_bad_pos', NULL, NULL)
(-104, '42', '000', 13, 937, 'dsql_cte_wrong_reference', NULL, NULL)
(-104, '42', '000', 13, 938, 'dsql_cte_cycle', NULL, NULL)
(-104, '42', '000', 13, 939, 'dsql_cte_outer_join', NULL, NULL)
(-104, '42', '000', 13, 940, 'dsql_cte_mult_references', NULL, NULL)
(-104, '42', '000', 13, 941, 'dsql_cte_not_a_union', NULL, NULL)
(-104, '42', '000', 13, 942, 'dsql_cte_nonrecurs_after_recurs', NULL, NULL)
(-104, '42', '000', 13, 943, 'dsql_cte_wrong_clause', NULL, NULL)
(-104, '42', '000', 13, 944, 'dsql_cte_union_all', NULL, NULL)
(-104, '42', '000', 13, 945, 'dsql_cte_miss_nonrecursive', NULL, NULL)
(-104, '42', '000', 13, 946, 'dsql_cte_nested_with', NULL, NULL)
(-104, '42', '000', 13, 947, 'dsql_col_more_than_once_using', NULL, NULL)
(-901, 'HY', '000', 13, 948, 'dsql_unsupp_feature_dialect', NULL, NULL)
(-104, '42', '000', 13, 949, 'dsql_cte_not_used', NULL, NULL)
(-104, '42', '000', 13, 950, 'dsql_col_more_than_once_view', NULL, NULL)
(-901, 'HY', '000', 13, 951, 'dsql_unsupported_in_auto_trans', NULL, NULL)
-- For the following values I simply copied the error code and SQL codes from expression_eval_err
(-833, '42', '000', 13, 952, 'dsql_eval_unknode', NULL, NULL)
(-833, '42', '000', 13, 953, 'dsql_agg_wrongarg', NULL, NULL)
(-833, '42', '000', 13, 954, 'dsql_agg2_wrongarg', NULL, NULL)
(-833, '42', '000', 13, 955, 'dsql_nodateortime_pm_string', NULL, NULL)
(-833, '42', '000', 13, 956, 'dsql_invalid_datetime_subtract', NULL, NULL)
(-833, '42', '000', 13, 957, 'dsql_invalid_dateortime_add', NULL, NULL)
(-833, '42', '000', 13, 958, 'dsql_invalid_type_minus_date', NULL, NULL)
(-833, '42', '000', 13, 959, 'dsql_nostring_addsub_dial3', NULL, NULL)
(-833, '42', '000', 13, 960, 'dsql_invalid_type_addsub_dial3', NULL, NULL)
(-833, '42', '000', 13, 961, 'dsql_invalid_type_multip_dial1', NULL, NULL)
(-833, '42', '000', 13, 962, 'dsql_nostring_multip_dial3', NULL, NULL)
(-833, '42', '000', 13, 963, 'dsql_invalid_type_multip_dial3', NULL, NULL)
(-833, '42', '000', 13, 964, 'dsql_mustuse_numeric_div_dial1', NULL, NULL)
(-833, '42', '000', 13, 965, 'dsql_nostring_div_dial3', NULL, NULL)
(-833, '42', '000', 13, 966, 'dsql_invalid_type_div_dial3', NULL, NULL)
(-833, '42', '000', 13, 967, 'dsql_nostring_neg_dial3', NULL, NULL)
(-833, '42', '000', 13, 968, 'dsql_invalid_type_neg', NULL, NULL)
-- End of expression_eval_err subcodes
(-104, '54', '011', 13, 969, 'dsql_max_distinct_items', NULL, NULL)
(-901, '42', '000', 13, 970, 'dsql_alter_charset_failed', NULL, NULL);
(-901, '42', '000', 13, 971, 'dsql_comment_on_failed', NULL, NULL);
(-901, '42', '000', 13, 972, 'dsql_create_func_failed', NULL, NULL);
(-901, '42', '000', 13, 973, 'dsql_alter_func_failed', NULL, NULL);
(-901, '42', '000', 13, 974, 'dsql_create_alter_func_failed', NULL, NULL);
(-901, '42', '000', 13, 975, 'dsql_drop_func_failed', NULL, NULL);
(-901, '42', '000', 13, 976, 'dsql_recreate_func_failed', NULL, NULL);
(-901, '42', '000', 13, 977, 'dsql_create_proc_failed', NULL, NULL);
(-901, '42', '000', 13, 978, 'dsql_alter_proc_failed', NULL, NULL);
(-901, '42', '000', 13, 979, 'dsql_create_alter_proc_failed', NULL, NULL);
(-901, '42', '000', 13, 980, 'dsql_drop_proc_failed', NULL, NULL);
(-901, '42', '000', 13, 981, 'dsql_recreate_proc_failed', NULL, NULL);
(-901, '42', '000', 13, 982, 'dsql_create_trigger_failed', NULL, NULL);
(-901, '42', '000', 13, 983, 'dsql_alter_trigger_failed', NULL, NULL);
(-901, '42', '000', 13, 984, 'dsql_create_alter_trigger_failed', NULL, NULL);
(-901, '42', '000', 13, 985, 'dsql_drop_trigger_failed', NULL, NULL);
(-901, '42', '000', 13, 986, 'dsql_recreate_trigger_failed', NULL, NULL);
(-901, '42', '000', 13, 987, 'dsql_create_collation_failed', NULL, NULL);
(-901, '42', '000', 13, 988, 'dsql_drop_collation_failed', NULL, NULL);
(-901, '42', '000', 13, 989, 'dsql_create_domain_failed', NULL, NULL);
(-901, '42', '000', 13, 990, 'dsql_alter_domain_failed', NULL, NULL);
(-901, '42', '000', 13, 991, 'dsql_drop_domain_failed', NULL, NULL);
(-901, '42', '000', 13, 992, 'dsql_create_except_failed', NULL, NULL);
(-901, '42', '000', 13, 993, 'dsql_alter_except_failed', NULL, NULL);
(-901, '42', '000', 13, 994, 'dsql_create_alter_except_failed', NULL, NULL);
(-901, '42', '000', 13, 995, 'dsql_recreate_except_failed', NULL, NULL);
(-901, '42', '000', 13, 996, 'dsql_drop_except_failed', NULL, NULL);
(-901, '42', '000', 13, 997, 'dsql_create_sequence_failed', NULL, NULL);
(-901, '42', '000', 13, 998, 'dsql_create_table_failed', NULL, NULL);
(-901, '42', '000', 13, 999, 'dsql_alter_table_failed', NULL, NULL);
(-901, '42', '000', 13, 1000, 'dsql_drop_table_failed', NULL, NULL);
(-901, '42', '000', 13, 1001, 'dsql_recreate_table_failed', NULL, NULL);
(-901, '42', '000', 13, 1002, 'dsql_create_pack_failed', NULL, NULL);
(-901, '42', '000', 13, 1003, 'dsql_alter_pack_failed', NULL, NULL);
(-901, '42', '000', 13, 1004, 'dsql_create_alter_pack_failed', NULL, NULL);
(-901, '42', '000', 13, 1005, 'dsql_drop_pack_failed', NULL, NULL);
(-901, '42', '000', 13, 1006, 'dsql_recreate_pack_failed', NULL, NULL);
(-901, '42', '000', 13, 1007, 'dsql_create_pack_body_failed', NULL, NULL);
(-901, '42', '000', 13, 1008, 'dsql_drop_pack_body_failed', NULL, NULL);
(-901, '42', '000', 13, 1009, 'dsql_recreate_pack_body_failed', NULL, NULL);
(-901, '42', '000', 13, 1010, 'dsql_create_view_failed', NULL, NULL);
(-901, '42', '000', 13, 1011, 'dsql_alter_view_failed', NULL, NULL);
(-901, '42', '000', 13, 1012, 'dsql_create_alter_view_failed', NULL, NULL);
(-901, '42', '000', 13, 1013, 'dsql_recreate_view_failed', NULL, NULL);
(-901, '42', '000', 13, 1014, 'dsql_drop_view_failed', NULL, NULL);
(-901, '42', '000', 13, 1015, 'dsql_drop_sequence_failed', NULL, NULL);
(-901, '42', '000', 13, 1016, 'dsql_recreate_sequence_failed', NULL, NULL);
(-901, '42', '000', 13, 1017, 'dsql_drop_index_failed', NULL, NULL);
(-901, '42', '000', 13, 1018, 'dsql_drop_filter_failed', NULL, NULL);
(-901, '42', '000', 13, 1019, 'dsql_drop_shadow_failed', NULL, NULL);
(-901, '42', '000', 13, 1020, 'dsql_drop_role_failed', NULL, NULL);
(-901, '42', '000', 13, 1021, 'dsql_drop_user_failed', NULL, NULL);
(-901, '42', '000', 13, 1022, 'dsql_create_role_failed', NULL, NULL);
(-901, '42', '000', 13, 1023, 'dsql_alter_role_failed', NULL, NULL);
(-901, '42', '000', 13, 1024, 'dsql_alter_index_failed', NULL, NULL);
(-901, '42', '000', 13, 1025, 'dsql_alter_database_failed', NULL, NULL);
(-901, '42', '000', 13, 1026, 'dsql_create_shadow_failed', NULL, NULL);
(-901, '42', '000', 13, 1027, 'dsql_create_filter_failed', NULL, NULL);
(-901, '42', '000', 13, 1028, 'dsql_create_index_failed', NULL, NULL);
(-901, '42', '000', 13, 1029, 'dsql_create_user_failed', NULL, NULL);
(-901, '42', '000', 13, 1030, 'dsql_alter_user_failed', NULL, NULL);
(-901, '42', '000', 13, 1031, 'dsql_grant_failed', NULL, NULL);
(-901, '42', '000', 13, 1032, 'dsql_revoke_failed', NULL, NULL);
(-104, '42', '000', 13, 1033, 'dsql_cte_recursive_aggregate', NULL, NULL)
(-901, '42', '000', 13, 1034, 'dsql_mapping_failed', NULL, NULL)
(-901, '42', '000', 13, 1035, 'dsql_alter_sequence_failed', NULL, NULL)
(-901, '42', '000', 13, 1036, 'dsql_create_generator_failed', NULL, NULL)
(-901, '42', '000', 13, 1037, 'dsql_set_generator_failed', NULL, NULL)
(-104, '42', '000', 13, 1038, 'dsql_wlock_simple', NULL, NULL)
(-104, '42', '000', 13, 1039, 'dsql_firstskip_rows', NULL, NULL)
(-104, '42', '000', 13, 1040, 'dsql_wlock_aggregates', NULL, NULL)
(-104, '42', '000', 13, 1041, 'dsql_wlock_conflict', NULL, NULL)
(-901, '07', '002', 13, 1042, 'dsql_max_exception_arguments', NULL, NULL)
(-901, '42', '000', 13, 1043, 'dsql_string_byte_length', NULL, NULL)
(-901, '42', '000', 13, 1044, 'dsql_string_char_length', NULL, NULL)
(-901, '07', '002', 13, 1045, 'dsql_max_nesting', NULL, NULL)
-- GSEC
(-901, '00', '000', 18, 15, 'gsec_cant_open_db', NULL, NULL)
(-901, '00', '000', 18, 16, 'gsec_switches_error', NULL, NULL)
(-901, '00', '000', 18, 17, 'gsec_no_op_spec', NULL, NULL)
(-901, '00', '000', 18, 18, 'gsec_no_usr_name', NULL, NULL)
(-901, '00', '000', 18, 19, 'gsec_err_add', NULL, NULL)
(-901, '00', '000', 18, 20, 'gsec_err_modify', NULL, NULL)
(-901, '00', '000', 18, 21, 'gsec_err_find_mod', NULL, NULL)
(-901, '00', '000', 18, 22, 'gsec_err_rec_not_found', NULL, NULL)
(-901, '00', '000', 18, 23, 'gsec_err_delete', NULL, NULL)
(-901, '00', '000', 18, 24, 'gsec_err_find_del', NULL, NULL)
(-901, '00', '000', 18, 28, 'gsec_err_find_disp', NULL, NULL)
(-901, '00', '000', 18, 29, 'gsec_inv_param', NULL, NULL)
(-901, '00', '000', 18, 30, 'gsec_op_specified', NULL, NULL)
(-901, '00', '000', 18, 31, 'gsec_pw_specified', NULL, NULL)
(-901, '00', '000', 18, 32, 'gsec_uid_specified', NULL, NULL)
(-901, '00', '000', 18, 33, 'gsec_gid_specified', NULL, NULL)
(-901, '00', '000', 18, 34, 'gsec_proj_specified', NULL, NULL)
(-901, '00', '000', 18, 35, 'gsec_org_specified', NULL, NULL)
(-901, '00', '000', 18, 36, 'gsec_fname_specified', NULL, NULL)
(-901, '00', '000', 18, 37, 'gsec_mname_specified', NULL, NULL)
(-901, '00', '000', 18, 38, 'gsec_lname_specified', NULL, NULL)
(-901, '00', '000', 18, 40, 'gsec_inv_switch', NULL, NULL)
(-901, '00', '000', 18, 41, 'gsec_amb_switch', NULL, NULL)
(-901, '00', '000', 18, 42, 'gsec_no_op_specified', NULL, NULL)
(-901, '00', '000', 18, 43, 'gsec_params_not_allowed', NULL, NULL)
(-901, '00', '000', 18, 44, 'gsec_incompat_switch', NULL, NULL)
(-901, '00', '000', 18, 76, 'gsec_inv_username', NULL, NULL)
(-901, '00', '000', 18, 77, 'gsec_inv_pw_length', NULL, NULL)
(-901, '00', '000', 18, 78, 'gsec_db_specified', NULL, NULL)
(-901, '00', '000', 18, 79, 'gsec_db_admin_specified', NULL, NULL)
(-901, '00', '000', 18, 80, 'gsec_db_admin_pw_specified', NULL, NULL)
(-901, '00', '000', 18, 81, 'gsec_sql_role_specified', NULL, NULL)
-- GSTAT
(-901, '00', '000', 21, 1, 'gstat_unknown_switch', NULL, NULL)
(-901, '00', '000', 21, 2, 'gstat_retry', NULL, NULL)
(-901, '00', '000', 21, 3, 'gstat_wrong_ods', NULL, NULL)
(-901, '00', '000', 21, 4, 'gstat_unexpected_eof', NULL, NULL)
(-901, '00', '000', 21, 29, 'gstat_open_err', NULL, NULL)
(-901, '00', '000', 21, 30, 'gstat_read_err', NULL, NULL)
(-901, '00', '000', 21, 31, 'gstat_sysmemex', NULL, NULL)
-- FBSVCMGR
(-901, '00', '000', 22, 1, 'fbsvcmgr_bad_am', NULL, NULL)
(-901, '00', '000', 22, 2, 'fbsvcmgr_bad_wm', NULL, NULL)
(-901, '00', '000', 22, 3, 'fbsvcmgr_bad_rs', NULL, NULL)
(-901, '00', '000', 22, 4, 'fbsvcmgr_info_err', NULL, NULL)
(-901, '00', '000', 22, 5, 'fbsvcmgr_query_err', NULL, NULL)
(-901, '00', '000', 22, 6, 'fbsvcmgr_switch_unknown', NULL, NULL)
(-901, '00', '000', 22, 47, 'fbsvcmgr_bad_sm', NULL, NULL)
(-901, '00', '000', 22, 48, 'fbsvcmgr_fp_open', NULL, NULL)
(-901, '00', '000', 22, 49, 'fbsvcmgr_fp_read', NULL, NULL)
(-901, '00', '000', 22, 50, 'fbsvcmgr_fp_empty', NULL, NULL)
(-901, '00', '000', 22, 52, 'fbsvcmgr_bad_arg', NULL, NULL)
-- UTILITIES
(-901, '00', '000', 23, 1, 'utl_trusted_switch', NULL, NULL)
-- NBACKUP
(-901, '00', '000', 24, 29, 'nbackup_missing_param', NULL, NULL)
(-901, '00', '000', 24, 30, 'nbackup_allowed_switches', NULL, NULL)
(-901, '00', '000', 24, 31, 'nbackup_unknown_param', NULL, NULL)
(-901, '00', '000', 24, 32, 'nbackup_unknown_switch', NULL, NULL)
(-901, '00', '000', 24, 33, 'nbackup_nofetchpw_svc', NULL, NULL)
(-901, '00', '000', 24, 34, 'nbackup_pwfile_error', NULL, NULL)
(-901, '00', '000', 24, 35, 'nbackup_size_with_lock', NULL, NULL)
(-901, '00', '000', 24, 36, 'nbackup_no_switch', NULL, NULL)
(-901, '00', '000', 24, 39, 'nbackup_err_read', NULL, NULL)
(-901, '00', '000', 24, 40, 'nbackup_err_write', NULL, NULL)
(-901, '00', '000', 24, 41, 'nbackup_err_seek', NULL, NULL)
(-901, '00', '000', 24, 42, 'nbackup_err_opendb', NULL, NULL)
(-901, '00', '000', 24, 43, 'nbackup_err_fadvice', NULL, NULL)
(-901, '00', '000', 24, 44, 'nbackup_err_createdb', NULL, NULL)
(-901, '00', '000', 24, 45, 'nbackup_err_openbk', NULL, NULL)
(-901, '00', '000', 24, 46, 'nbackup_err_createbk', NULL, NULL)
(-901, '00', '000', 24, 47, 'nbackup_err_eofdb', NULL, NULL)
(-901, '00', '000', 24, 48, 'nbackup_fixup_wrongstate', NULL, NULL)
(-901, '00', '000', 24, 49, 'nbackup_err_db', NULL, NULL)
(-901, '00', '000', 24, 50, 'nbackup_userpw_toolong', NULL, NULL)
(-901, '00', '000', 24, 51, 'nbackup_lostrec_db', NULL, NULL)
(-901, '00', '000', 24, 52, 'nbackup_lostguid_db', NULL, NULL)
(-901, '00', '000', 24, 53, 'nbackup_err_eofhdrdb', NULL, NULL)
(-901, '00', '000', 24, 54, 'nbackup_db_notlock', NULL, NULL)
(-901, '00', '000', 24, 55, 'nbackup_lostguid_bk', NULL, NULL)
(-901, '00', '000', 24, 56, 'nbackup_page_changed', NULL, NULL)
(-901, '00', '000', 24, 57, 'nbackup_dbsize_inconsistent', NULL, NULL)
(-901, '00', '000', 24, 58, 'nbackup_failed_lzbk', NULL, NULL)
(-901, '00', '000', 24, 59, 'nbackup_err_eofhdrbk', NULL, NULL)
(-901, '00', '000', 24, 60, 'nbackup_invalid_incbk', NULL, NULL)
(-901, '00', '000', 24, 61, 'nbackup_unsupvers_incbk', NULL, NULL)
(-901, '00', '000', 24, 62, 'nbackup_invlevel_incbk', NULL, NULL)
(-901, '00', '000', 24, 63, 'nbackup_wrong_orderbk', NULL, NULL)
(-901, '00', '000', 24, 64, 'nbackup_err_eofbk', NULL, NULL)
(-901, '00', '000', 24, 65, 'nbackup_err_copy', NULL, NULL)
(-901, '00', '000', 24, 66, 'nbackup_err_eofhdr_restdb', NULL, NULL)
(-901, '00', '000', 24, 67, 'nbackup_lostguid_l0bk', NULL, NULL)
(-901, '00', '000', 24, 71, 'nbackup_switchd_parameter', NULL, NULL)
(-901, '08', '006', 24, 73, 'nbackup_user_stop', NULL, NULL)
(-901, '54', '023', 24, 75, 'nbackup_deco_parse', NULL, NULL)
-- FBTRACEMGR
(-901, '00', '000', 25, 30, 'trace_conflict_acts', NULL, NULL)
(-901, '00', '000', 25, 31, 'trace_act_notfound', NULL, NULL)
(-901, '00', '000', 25, 32, 'trace_switch_once', NULL, NULL)
(-901, '00', '000', 25, 33, 'trace_param_val_miss', NULL, NULL)
(-901, '00', '000', 25, 34, 'trace_param_invalid', NULL, NULL)
(-901, '00', '000', 25, 35, 'trace_switch_unknown', NULL, NULL)
(-901, '00', '000', 25, 36, 'trace_switch_svc_only', NULL, NULL)
(-901, '00', '000', 25, 37, 'trace_switch_user_only', NULL, NULL)
(-901, '00', '000', 25, 38, 'trace_switch_param_miss', NULL, NULL)
(-901, '00', '000', 25, 39, 'trace_param_act_notcompat', NULL, NULL)
(-901, '00', '000', 25, 40, 'trace_mandatory_switch_miss' NULL, NULL)
stop

COMMIT WORK;
